library(growth)
library(gnlm)
library(repeated)

data <- read.table("lutein2.dat",skip=4)
times <- c(1,2,3,4,5,5.5,6,6.5,7,7.5,8,8.5,9,9.5,10)
suck <- c(rep(0,16),rep(1,16))
postpart <- matrix(c(rep(0,5),rep(1,10)),ncol=15,nrow=32,byrow=T)
resp <- restovec(data,name="lutein",times=times)
resp <- transform(resp,llutein=log(lutein))
reps <- rmna(resp,ccov=tcctomat(suck),tvcov=tvctomat(postpart))
resp1 <- restovec(data[1:16,],name="lutein",times=times)
resp1 <- transform(resp1,llutein=log(lutein))
reps1 <- rmna(resp1,tvcov=tvctomat(postpart[1:16,],name="postpart"))
resp2 <- restovec(data[17:32,],name="lutein",times=times)
resp2 <- transform(resp2,llutein=log(lutein))
reps2 <- rmna(resp2,tvcov=tvctomat(postpart[17:32,],name="postpart"))

if(interactive()){
postscript("lutein.eps",height=5)
par(mfcol=c(1,2),font.main=1,mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0),font.main=1)
plot(reps,name="lutein",nind=1:16,main="Nonsuckled cows",xlab="Days",
	ylab="Luteinizing hormone",xlim=c(0,10))
plot(reps,name="lutein",nind=17:32,main="Suckled cows",ylab="",
	xlab="Days",xlim=c(0,10))
dev.off()
}

# Chapter 10
# ARCH models
gnlr(llutein,mu=~suck*times,pmu=c(6,0,0,0),psh=0.16,envir=reps)
gar(llutein,mu=~suck*times,preg=c(6,0,0,0),psh=0.16,parch=0.1,envir=reps)
gar(llutein,mu=~suck*times,preg=c(6,0,0,0),pdep=0.3,psh=0.16,envir=reps)
gar(llutein,mu=~suck*times,preg=c(6,0,0,0),pdep=0.3,psh=0.16,
	parch=0.1,envir=reps)
gar(llutein,mu=~suck*times,preg=c(6,0,0,0),pdep=0.4,psh=0.1,
	parch=0.5,arch="abs",envir=reps,iter=200)
gar(llutein,mu=~suck*times,preg=c(6,0,0,0),pdep=0.3,psh=0.16,
	parch=0.1,arch="exp",envir=reps)

gnlr3(llutein,dist="Student",mu=~suck*times,pmu=c(6,0,0,0),psh=0.16,
	pfam=2,envir=reps)
gar(llutein,dist="Student",mu=~suck*times,preg=c(6,0,0,0),pdep=0.3,
	psh=c(0.16,10),envir=reps)
gar(llutein,dist="Student",mu=~suck*times,preg=c(6,0,0,0),pdep=0.3,
	psh=c(0.16,10),parch=0.1,envir=reps)
gar(llutein,dist="Student",mu=~suck*times,preg=c(6,0,0,0),pdep=0.3,
	psh=c(0.16,10),arch="abs",parch=0.1,envir=reps)
gar(llutein,dist="Student",mu=~suck*times,preg=c(6,0,0,0),pdep=0.3,
	psh=c(0.16,10),arch="exp",parch=0.1,envir=reps)

gnlr3(llutein,dist="skew Laplace",mu=~suck*times,pmu=c(5.9,0,0.07,0),psh=-1.2,
	pfam=-0.1,envir=reps)
gar(llutein,dist="skew Laplace",mu=~suck*times,preg=c(5.91,0.021,0.07,-0.039),
	pdep=0.55,psh=c(0.22,0.9),envir=reps)
gar(lutein,dist="skew Laplace",mu=~suck*times,
	preg=c(5.91,0.021,0.059,-0.039),pdep=0.5,psh=c(0.22,0.9),
	parch=0.1,transform="log",envir=reps)
print(zarch <- gar(lutein,dist="skew Laplace",mu=~suck*times,
	preg=c(5.92,0.023,0.059,-0.033),pdep=0.53,psh=c(0.2,0.93),
	arch="abs",parch=0.2,transform="log",envir=reps,iter=200))
gar(lutein,dist="skew Laplace",mu=~suck*times,
	preg=c(5.91,0.021,0.059,-0.039),pdep=0.53,psh=c(0.22,0.93),
	arch="exp",parch=0.5,transform="log",envir=reps)

gar(lutein,dist="skew Laplace",mu=~suck*times,preg=c(350,-52,0,1.5),
	pdep=0.15,psh=c(100,0.5),parch=0.00000006,envir=reps)

gnlr3(llutein,dist="power exp",mu=~suck*times,pmu=c(5.9,0,0.07,0),psh=-1.2,
	pfam=-0.1,envir=reps)
gar(llutein,dist="power exp",mu=~suck*times,preg=c(6,0,0,0),pdep=0.49,
	psh=c(0.16,1),envir=reps)
gar(llutein,dist="power exp",mu=~suck*times,preg=c(6,0,0,0),pdep=0.49,
	psh=c(0.16,1),parch=0.035,envir=reps)
gar(llutein,dist="power exp",mu=~suck*times,preg=c(6,0,0,0),pdep=0.49,
	psh=c(0.16,1),arch="abs",parch=0.035,envir=reps,iter=200)
gar(llutein,dist="power exp",mu=~suck*times,preg=c(6,0,0,0),pdep=0.49,
	psh=c(0.16,1),arch="exp",parch=0.035,envir=reps)

gnlr3(llutein,dist="Burr",mu=~suck*times,pmu=c(5.9,0,0.07,0),psh=-1.2,
	pfam=-0.1,envir=reps)
gar(llutein,dist="Burr",mu=~suck*times,preg=c(5.9,0,0,0),pdep=0.3,
	psh=c(36,0.8),envir=reps)
gar(llutein,dist="Burr",mu=~suck*times,preg=c(5.9,0,0,0),pdep=0.3,
	psh=c(36,0.8),parch=0.1,envir=reps)
gar(llutein,dist="Burr",mu=~suck*times,preg=c(5.9,0,0,0),pdep=0.3,
	psh=c(36,0.8),arch="abs",parch=0.1,envir=reps)
gar(llutein,dist="Burr",mu=~suck*times,preg=c(5.9,0,0,0),pdep=0.3,
	psh=c(6,0.8),arch="exp",parch=-0.1,envir=reps,iter=200)

gar(lutein,dist="Burr",mu=~suck*times,preg=c(350,4,24,-20),pdep=0.2,
	psh=c(5.7,0.8),envir=reps)
gar(lutein,dist="Burr",mu=~suck*times,preg=c(350,4,24,-20),pdep=0.2,
	psh=c(5.7,0.8),parch=0.000000000001,envir=reps)
gar(lutein,dist="Burr",mu=~suck*times,preg=c(350,4,24,-20),pdep=0.2,
	psh=c(5.7,0.8),parch=-50,arch="exp",envir=reps)

if(interactive()){
postscript("lutein6.eps",height=5)
par(mfcol=c(1,2),font.main=1,mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0),font.main=1)
plot(iprofile(zarch),nind=1:2,xlim=c(0,10),ylim=c(0,2000),pch=0:1,lty=2:3,
	main="Nonsuckled cows",xlab="Days",ylab="Luteinizing hormone")
plot(mprofile(zarch),nind=1,add=T)
legend(0,1500,legend=c("Marginal profile","Cow 1","Cow 2"),bty="n",
	lty=1:3,pch=-1:1)
plot(iprofile(zarch),nind=17:18,xlim=c(0,10),ylim=c(0,2000),pch=0:1,lty=2:3,
	main="Suckled cows",xlab="Days",ylab="")
plot(mprofile(zarch),nind=17,add=T)
legend(0,1500,legend=c("Marginal profile","Cow 17","Cow 18"),bty="n",
	lty=1:3,pch=-1:1)
dev.off()
postscript("luteinarch.eps",height=5)
par(mfcol=c(1,2),font.main=1,mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0),font.main=1)
plot(times,volatility(zarch,nind=1),xlim=c(0,10),ylim=c(0,1.5),type="l",
	lty=2,main="Nonsuckled cows",xlab="Days",
	ylab=expression(sqrt(phi)))
lines(times,volatility(zarch,nind=2),lty=3)
legend(0,1.5,legend=c("Cow 1","Cow 2"),bty="n",lty=2:3)
plot(times,volatility(zarch,nind=17),xlim=c(0,10),ylim=c(0,1.5),type="l",
	lty=2,main="Suckled cows",xlab="Days",ylab="")
lines(times,volatility(zarch,nind=18),lty=3)
legend(0,1.5,legend=c("Cow 17","Cow 18"),bty="n",lty=2:3)
dev.off()
}

# Chapter 11
# AR(1)
# normal distribution
carma(lutein,envir=reps)
carma(lutein,ccov=~suck,envir=reps)
carma(lutein,torder=1,envir=reps)
carma(lutein,ccov=~suck,torder=1,envir=reps)
carma(lutein,ccov=~suck,torder=1,interaction=1,envir=reps)
carma(lutein,envir=reps,par=0.3)
carma(lutein,ccov=~suck,envir=reps,par=0.3)
carma(lutein,torder=1,envir=reps,par=0.3)
carma(lutein,ccov=~suck,torder=1,envir=reps,par=0.4)
carma(lutein,ccov=~suck,torder=1,interaction=1,envir=reps,par=0.4)

# log normal distribution
carma(lutein,trans="log",envir=reps)
carma(lutein,ccov=~suck,trans="log",envir=reps)
carma(lutein,torder=1,trans="log",envir=reps)
carma(lutein,ccov=~suck,torder=1,trans="log",envir=reps)
carma(lutein,ccov=~suck,torder=1,interaction=1,trans="log",envir=reps)
carma(lutein,trans="log",par=0.1,envir=reps)
carma(lutein,ccov=~suck,trans="log",par=0.3,envir=reps)
carma(lutein,torder=1,trans="log",par=0.4,envir=reps)
carma(lutein,ccov=~suck,torder=1,trans="log",par=0.3,envir=reps)
print(zlar <- carma(lutein,ccov=~suck,torder=1,interaction=1,trans="log",
	par=0.3,envir=reps))
carma(lutein,ccov=~suck,torder=2,trans="log",par=0.3,envir=reps)
carma(lutein,ccov=~suck,torder=2,interaction=2,trans="log",par=0.3,envir=reps)

if(interactive()){
postscript("lutein2.eps",height=5)
par(mfcol=c(1,2),font.main=1,mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0),font.main=1)
plot(iprofile(zlar),nind=1:2,xlim=c(0,10),ylim=c(0,2000),pch=0:1,lty=2:3,
	main="Nonsuckled cows",xlab="Days",ylab="Luteinizing hormone")
plot(mprofile(zlar,ccov=0,plotse=F),add=T)
legend(0,1500,legend=c("Marginal profile","Cow 1","Cow 2"),bty="n",
	lty=1:3,pch=-1:1)
plot(iprofile(zlar),nind=17:18,xlim=c(0,10),ylim=c(0,2000),pch=0:1,lty=2:3,
	main="Suckled cows",xlab="Days",ylab="")
plot(mprofile(zlar,ccov=1,plotse=F),add=T)
legend(0,1500,legend=c("Marginal profile","Cow 17","Cow 18"),bty="n",
	lty=1:3,pch=-1:1)
dev.off()
}

# time-varying covariate (not fitted by dynamic linear model)
elliptic(lutein,ccov=~suck,torder=1,interaction=1,par=0.3,trans="log",
	envir=reps)
print(zartv1 <- elliptic(lutein,ccov=~suck,tvcov=~postpart,torder=1,
	interaction=1,par=0.3,trans="log",envir=reps))
elliptic(lutein,model=~times*suck+postpart*suck,par=0.3,trans="log",
	preg=c(zartv1$beta,0),envir=reps)

# hidden Markov models

#first independence models
gnlr(llutein,dist="normal",pmu=c(6,0),mu=~suck,envir=reps,
	psh=0)
gnlr(lutein,dist="gamma",pmu=c(500,-100),mu=~suck,envir=reps,
	psh=0)
gnlr(lutein,dist="Weibull",pmu=c(500,-100),mu=~suck,envir=reps,
	psh=0)
gnlr(lutein,dist="inverse Gauss",pmu=c(500,-100),mu=~suck,envir=reps,
	psh=0)
gnlr3(lutein,dist="Burr",pmu=c(500,-100),mu=~suck,envir=reps,
	psh=3,pfam=0.4)
gnlr3(llutein,dist="Burr",pmu=c(6,-0.3),mu=~suck,envir=reps,
	psh=3,pfam=0.4)
gnlr3(llutein,dist="Student",pmu=c(6,-0.3),mu=~suck,envir=reps,
	psh=3,pfam=0.4)
gnlr3(llutein,dist="power exp",pmu=c(6,-0.3),mu=~suck,envir=reps,
	psh=3,pfam=0)
gnlr3(llutein,dist="skew Laplace",pmu=c(6,-0.3),mu=~suck,envir=reps,
	psh=3,pfam=0)

chidden(llutein,dist="normal",pcmu=c(6,0,6.7,0),cmu=~suck,envir=reps,
	pgamma=matrix(c(-0.12,0.13,0.12,-0.13),ncol=2),psh=c(0.05,0.17))
chidden(lutein,dist="gamma",pcmu=c(950,-450,450,-125),envir=reps,
	cmu=~suck,pgamma=matrix(c(-0.15,0.16,0.15,-0.16),ncol=2),psh=c(4,8))
chidden(lutein,dist="Weibull",pcmu=c(600,-100,1400,-700),envir=reps,
	cmu=~suck,pgamma=matrix(c(-0.15,0.16,0.15,-0.16),ncol=2),psh=c(4,1))
chidden(lutein,dist="inverse Gauss",pcmu=c(900,-300,500,-200),envir=reps,
	cmu=~suck,pgamma=matrix(c(-0.15,0.16,0.15,-0.16),ncol=2),
	psh=c(0.0002,0.0002))
chidden(lutein,dist="Burr",pcmu=c(600,-100,400,-100),cmu=~suck,envir=reps,
	pgamma=matrix(c(-0.11,0.1,0.11,-0.1),ncol=2),psh=10,pfam=0.4)
chidden(llutein,dist="Burr",pcmu=c(6,-0.3,6,-0.2),cmu=~suck,envir=reps,
	pgamma=matrix(c(-0.11,0.1,0.11,-0.1),ncol=2),psh=60,pfam=0.4)
chidden(llutein,dist="Student",pcmu=c(6,0.2,6,-0.2),cmu=~suck,envir=reps,
	pgamma=matrix(c(-0.11,0.1,0.11,-0.1),ncol=2),psh=0.2,pfam=0.4)
chidden(llutein,dist="power exp",pcmu=c(6,0.2,6,-0.2),cmu=~suck,envir=reps,
	pgamma=matrix(c(-0.11,0.1,0.11,-0.1),ncol=2),psh=0.016,pfam=0.5)
chidden(llutein,dist="skew Laplace",pcmu=c(6,0.2,6,-0.2),cmu=~suck,envir=reps,
	pgamma=matrix(c(-0.11,0.1,0.11,-0.1),ncol=2),psh=0.2,pfam=0.4)

chidden(llutein,dist="normal",pcmu=c(6,6.7),envir=reps1,
	cmu=~1,pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=c(0.1,0.2))
chidden(llutein,dist="normal",pcmu=c(5.8,6.3),envir=reps2,
	cmu=~1,pgamma=matrix(c(-0.1,0.2,0.1,-0.2),ncol=2),psh=c(0.1,0.2))
chidden(lutein,dist="gamma",pcmu=c(500,1000),envir=reps1,
	cmu=~1,pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=c(8,4))
chidden(lutein,dist="gamma",pcmu=c(300,600),envir=reps2,
	cmu=~1,pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=c(8,4))
chidden(lutein,dist="Weibull",pcmu=c(700,2500),envir=reps1,
	cmu=~1,pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=c(4,1))
chidden(lutein,dist="Weibull",pcmu=c(500,800),envir=reps2,
	cmu=~1,pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=c(4,1))
chidden(lutein,dist="inverse Gau",cmu=~1,pcmu=c(700,2500),envir=reps1,
	pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=c(0.0002,0.0002))
chidden(lutein,dist="inverse Gau",cmu=~1,pcmu=c(300,600),envir=reps2,
	pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=c(0.0001,0.0001))
print(z1 <- chidden(lutein,dist="Burr",pcmu=c(300,450),envir=reps1,
	cmu=~1,pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=1,pfam=1))
mexp(z1$gamma)
print(z2 <- chidden(lutein,dist="Burr",pcmu=c(300,450),envir=reps2,
	cmu=~1,pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=1,pfam=1))
mexp(z2$gamma)
z1$aic+z2$aic
print(z1ar <- chidden(lutein,dist="Burr",pcmu=c(550,350),envir=reps1,
	cmu=~1,pgamma=matrix(c(-0.12,0.1,0.12,-0.1),ncol=2),psh=9.4,pfam=0.3,
	par=0.1))
print(z2ar <- chidden(lutein,dist="Burr",pcmu=c(475,285),envir=reps2,
	cmu=~1,pgamma=matrix(c(-0.04,0.06,0.04,-0.06),ncol=2),psh=10,pfam=0.5,
	par=0.1))
z1ar$aic+z2ar$aic
print(z1l <- chidden(llutein,dist="Burr",pcmu=c(6,6),envir=reps1,
	cmu=~1,pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=10,pfam=0.4))
mexp(z1l$gamma)
print(z2l <- chidden(llutein,dist="Burr",pcmu=c(6,6),envir=reps2,
	cmu=~1,pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=10,pfam=0.3))
mexp(z2l$gamma)
z1l$aic+z2l$aic
print(z1lar <- chidden(llutein,dist="Burr",pcmu=c(6,6),envir=reps1,
	cmu=~1,pgamma=matrix(c(-0.12,0.1,0.12,-0.1),ncol=2),psh=10,pfam=0.3,
	par=0.1))
print(z2lar <- chidden(llutein,dist="Burr",pcmu=c(6,6),envir=reps2,
	cmu=~1,pgamma=matrix(c(-0.04,0.06,0.04,-0.06),ncol=2),psh=10,pfam=0.5,
	par=0.1))
z1lar$aic+z2lar$aic

print(z1ls <- chidden(llutein,dist="Student",pcmu=c(6,6),envir=reps1,
	cmu=~1,pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=0.2,pfam=0.4))
mexp(z1ls$gamma)
print(z2ls <- chidden(llutein,dist="Student",pcmu=c(6,6),envir=reps2,
	cmu=~1,pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=0.2,pfam=0.3))
mexp(z2ls$gamma)
z1ls$aic+z2ls$aic
print(z1lpe <- chidden(llutein,dist="power exp",pcmu=c(6,6.5),envir=reps1,
	cmu=~1,pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=0.02,pfam=0.6))
mexp(z1lpe$gamma)
print(z2lpe <- chidden(llutein,dist="power exp",pcmu=c(6,6),envir=reps2,
	cmu=~1,pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=0.2,pfam=1))
mexp(z2lpe$gamma)
z1lpe$aic+z2lpe$aic
print(z1lsl <- chidden(llutein,dist="skew Laplace",pcmu=c(6.4,5.9),envir=reps1,
	cmu=~1,pgamma=matrix(c(-0.13,0.11,0.13,-0.11),ncol=2),psh=0.24,
	pfam=0.62))
mexp(z1lsl$gamma)
print(z2lsl <- chidden(llutein,dist="skew Laplace",pcmu=c(6,6),envir=reps2,
	cmu=~1,pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=0.2,pfam=0.3))
mexp(z2lsl$gamma)
z1lsl$aic+z2lsl$aic

print(z1t <- chidden(lutein,dist="Burr",pmu=c(330,21,200,18),envir=reps1,
	mu=~times,pgamma=matrix(c(-0.0002,0.0009,0.0002,-0.0009),ncol=2),
	psh=11,pfam=0.25))
mexp(z1t$gamma)
print(z2t <- chidden(lutein,dist="Burr",pmu=c(300,0,450,0),envir=reps2,
	mu=~times,pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=1,pfam=1))
mexp(z2t$gamma)
z1t$aic+z2t$aic
z1t$aic+z2$aic
print(z1lt <- chidden(llutein,dist="Burr",pmu=c(6,0,6,0),envir=reps1,
	mu=~times,pgamma=matrix(c(-0.0002,0.0009,0.0002,-0.0009),ncol=2),
	psh=11,pfam=0.25))
mexp(z1lt$gamma)
print(z2lt <- chidden(llutein,dist="Burr",pmu=c(6,0,6,0),envir=reps2,
	mu=~times,pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=10,pfam=1))
mexp(z2lt$gamma)
z1lt$aic+z2lt$aic
print(z1tln <- chidden(llutein,dist="normal",pmu=c(6,0.15,6,0.05),envir=reps1,
	mu=~times,pgamma=matrix(c(-1.9,0.3,1.9,-0.3),ncol=2),psh=0.1))
print(z2tln <- chidden(llutein,dist="normal",pmu=c(6,0,6,0),envir=reps2,
	mu=~times,pgamma=matrix(c(-0.1,0.05,0.1,-0.05),ncol=2),psh=0.1))
z1tln$aic+z2tln$aic
print(z1tar <- chidden(lutein,dist="Burr",pmu=c(330,21,200,18),envir=reps1,
	mu=~times,pgamma=matrix(c(-0.0002,0.0009,0.0002,-0.0009),ncol=2),
	psh=11,pfam=0.25,par=0.1))
mexp(z1tar$gamma)
print(z2tar <- chidden(lutein,dist="Burr",pmu=c(435,6.7,289,-0.5),envir=reps2,
	mu=~times,pgamma=matrix(c(-0.04,0.06,0.04,-0.06),ncol=2),psh=10,
	pfam=0.5,par=0.1))
mexp(z2tar$gamma)
z1tar$aic+z2tar$aic
print(z1ltar <- chidden(llutein,dist="Burr",pmu=c(6,0,6,0),envir=reps1,
	mu=~times,pgamma=matrix(c(-0.0002,0.0009,0.0002,-0.0009),ncol=2),
	psh=11,pfam=0.25,par=0.1))
mexp(z1ltar$gamma)
print(z2ltar <- chidden(llutein,dist="Burr",pmu=c(6,0,6,0),
	mu=~times,pgamma=matrix(c(-0.04,0.06,0.04,-0.06),ncol=2),psh=10,
	pfam=0.5,par=0.1,envir=reps2))
mexp(z2ltar$gamma)
z1ltar$aic+z2ltar$aic

if(interactive()){
postscript("lutein3.eps")
par(mfrow=c(4,4),font.main=1,mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(times,z1t$filt[1,covind(z1t)==1],type="l",xlab="",ylab=expression(pi[2]),
	main="Cow 1",xlim=c(0,10),ylim=c(0,1))
for(i in 2:4)
plot(times,z1t$filt[1,covind(z1t)==i],type="l",xlab="",ylab="",
	main=paste("Cow ",i),xlim=c(0,10),ylim=c(0,1))
plot(times,z1t$filt[1,covind(z1t)==5],type="l",xlab="",ylab=expression(pi[2]),
	main="Cow 5",xlim=c(0,10),ylim=c(0,1))
for(i in 6:8)
plot(times,z1t$filt[1,covind(z1t)==i],type="l",xlab="",ylab="",
	main=paste("Cow ",i),xlim=c(0,10),ylim=c(0,1))
plot(times,z2$filt[1,covind(z2)==1],type="l",xlab="",ylab=expression(pi[2]),
	main="Cow 17",xlim=c(0,10),ylim=c(0,1))
for(i in 2:4)
plot(times,z2$filt[1,covind(z2)==i],type="l",xlab="",ylab="",
	main=paste("Cow ",i+16),xlim=c(0,10),ylim=c(0,1))
plot(times,z2$filt[1,covind(z2)==5],type="l",xlab="Days",
	ylab=expression(pi[2]),main="Cow 21",xlim=c(0,10),ylim=c(0,1))
for(i in 6:8)
plot(times,z2$filt[1,covind(z2)==i],type="l",xlab="Days",ylab="",
	main=paste("Cow ",i+16),xlim=c(0,10),ylim=c(0,1))
dev.off()
}

if(interactive()){
postscript("lutein4.eps",height=5)
par(mfcol=c(1,2),font.main=1,mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0),font.main=1)
plot(iprofile(z1t),nind=1:2,xlim=c(0,10),ylim=c(0,2000),pch=0:1,lty=2:3,
	main="Nonsuckled cows",xlab="Days",ylab="Luteinizing hormone")
plot(mprofile(z1t),nind=1,add=T)
legend(0,1500,legend=c("Marginal profile","Cow 1","Cow 2"),bty="n",
	lty=1:3,pch=-1:1)
plot(iprofile(z2),nind=1:2,xlim=c(0,10),ylim=c(0,2000),pch=0:1,lty=2:3,
	main="Suckled cows",xlab="Days",ylab="")
plot(mprofile(z2),nind=1,add=T)
legend(0,1500,legend=c("Marginal profile","Cow 17","Cow 18"),bty="n",
	lty=1:3,pch=-1:1)
dev.off()
}

print(z1tp <- chidden(lutein,dist="Burr",pmu=c(280,42,-125,210,20,-50),
	envir=reps1,mu=~times+postpart,psh=12,pfam=0.2,
	pgamma=matrix(c(-0.0002,0.0009,0.0002,-0.0009),ncol=2)))
mexp(z1tp$gamma)
print(z2p <- chidden(lutein,dist="Burr",pmu=c(300,0,450,0),envir=reps2,
	mu=~postpart,pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=1,pfam=1))
mexp(z2p$gamma)
z1p$aic+z2p$aic
print(z1ltp <- chidden(llutein,dist="Burr",pmu=c(6,0,0,6,0,0),
	envir=reps1,mu=~times+postpart,psh=12,pfam=0.2,
	pgamma=matrix(c(-0.0002,0.0009,0.0002,-0.0009),ncol=2)))
mexp(z1ltp$gamma)
print(z2ltp <- chidden(llutein,dist="Burr",pmu=c(6,0,6,0),envir=reps2,
	mu=~postpart,pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=1,pfam=1))
mexp(z2ltp$gamma)
z1ltp$aic+z2ltp$aic
print(z1tpar <- chidden(lutein,dist="Burr",pmu=c(280,42,-125,210,20,-50),
	envir=reps1,mu=~times+postpart,psh=12,pfam=0.2,par=0.1,
	pgamma=matrix(c(-0.0002,0.0009,0.0002,-0.0009),ncol=2)))
mexp(z1tpar$gamma)
print(z2par <- chidden(lutein,dist="Burr",pmu=c(470,10,300,-30),par=0.1,
	mu=~postpart,pgamma=matrix(c(-0.04,0.06,0.04,-0.06),ncol=2),
	psh=10,pfam=0.5,envir=reps2))
mexp(z2par$gamma)
z1tpar$aic+z2par$aic

kalseries(lutein,intensity="normal",ccov=~suck,torder=1,interaction=1,
	preg=c(152,72,18,7),psh=12.7,envir=reps)
kalseries(lutein,intensity="normal",ccov=~suck,torder=1,interaction=1,
	dep="Markov",preg=c(152,72,18,7),psh=12.7,pdep=0.4,envir=reps)
kalseries(lutein,intensity="normal",ccov=~suck,torder=1,interaction=1,
	preg=c(1,0,0,0),psh=0.16,envir=reps)
print(zknar <- kalseries(lutein,intensity="normal",ccov=~suck,torder=1,
	interaction=1,dep="Markov",preg=c(1,0,0,0),psh=0.16,pdep=0.4,
	transform="log",envir=reps))
print(zknar2 <- kalseries(lutein,intensity="normal",ccov=~suck,torder=1,
	tvc=~postpart,interaction=1,dep="Markov",
	preg=c(6.3,-0.26,0.062,-0.035),
	ptvc=-0.2,pinit=0.6,psh=0.082,pdep=0.24,transform="log",envir=reps))
print(zklar <- kalseries(lutein,intensity="logistic",ccov=~suck,torder=1,
	interaction=1,dep="Markov",preg=c(1,0,0,0),psh=0.16,pdep=0.4,
	transform="log",envir=reps))
print(zkcar <- kalseries(lutein,intensity="Cauchy",ccov=~suck,torder=1,
	interaction=1,dep="Markov",preg=c(6,-0.2,0,0),psh=0.2,pdep=0.65,
	transform="log",envir=reps))
print(zkwar <- kalseries(lutein,intensity="Weibull",ccov=~suck,torder=1,
	interaction=1,dep="Markov",preg=c(100,0,0,0),psh=0.16,pdep=0.4,
	envir=reps))
print(zkgar <- kalseries(lutein,intensity="gamma",ccov=~suck,torder=1,
	interaction=1,dep="Markov",preg=c(100,0,0,0),psh=0.16,pdep=0.4,
	envir=reps))

if(interactive()){
postscript("lutein5.eps",height=5)
par(mfcol=c(1,2),font.main=1,mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0),font.main=1)
plot(iprofile(zknar),nind=1:2,xlim=c(0,10),ylim=c(0,2000),pch=0:1,lty=2:3,
	main="Nonsuckled cows",xlab="Days",ylab="Luteinizing hormone")
plot(mprofile(zknar),nind=1,add=T)
legend(0,1500,legend=c("Marginal profile","Cow 1","Cow 2"),bty="n",
	lty=1:3,pch=-1:1)
plot(iprofile(zknar),nind=17:18,xlim=c(0,10),ylim=c(0,2000),pch=0:1,lty=2:3,
	main="Suckled cows",xlab="Days",ylab="")
plot(mprofile(zknar),nind=18,add=T)
legend(0,1500,legend=c("Marginal profile","Cow 17","Cow 18"),bty="n",
	lty=1:3,pch=-1:1)
dev.off()
}

# Chapter 14
# random coefficient models
carma(lutein,ccov=~suck,torder=1,interaction=1,pre=1,trans="log",envir=reps)
carma(lutein,ccov=~suck,torder=1,interaction=1,
	pre=c(0.35,0.05),pos=rbind(c(1,1),c(2,2)),trans="log",envir=reps)
carma(lutein,ccov=~suck,torder=1,interaction=1,trans="log",
	pre=c(0.5,0.01,0.085),pos=rbind(c(1,1),c(1,2),c(2,2)),envir=reps)

print(zarre <- carma(lutein,ccov=~suck,torder=1,interaction=1,par=0.3,pre=1,
	trans="log",envir=reps))
carma(lutein,ccov=~suck,torder=1,interaction=1,par=0.1,trans="log",
	pre=c(0.5,0.085),pos=rbind(c(1,1),c(2,2)),envir=reps)
carma(lutein,ccov=~suck,torder=1,interaction=1,par=0.1,trans="log",
	pre=c(0.5,0,0.085),pos=rbind(c(1,1),c(1,2),c(2,2)),envir=reps)

if(interactive()){
postscript("lutein7.eps",height=5)
par(mfcol=c(1,2),font.main=1,mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0),font.main=1)
plot(iprofile(zarre),nind=1:2,xlim=c(0,10),ylim=c(0,2000),pch=0:1,lty=2:3,
	main="Nonsuckled cows",xlab="Days",ylab="Luteinizing hormone")
plot(mprofile(zarre,ccov=0,plotse=F),nind=1,add=T)
legend(0,1500,legend=c("Marginal profile","Cow 1","Cow 2"),bty="n",
	lty=1:3,pch=-1:1)
plot(iprofile(zarre),nind=17:18,xlim=c(0,10),ylim=c(0,2000),pch=0:1,lty=2:3,
	main="Suckled cows",xlab="Days",ylab="")
plot(mprofile(zarre,ccov=1,plotse=F),add=T)
legend(0,1500,legend=c("Marginal profile","Cow 17","Cow 18"),bty="n",
	lty=1:3,pch=-1:1)
dev.off()
}

kalseries(lutein,intensity="normal",ccov=~suck,torder=1,
	interaction=1,dep="frailty",preg=c(1,0,0,0),psh=0.16,
	transform="log",envir=reps)
print(zknarf <- kalseries(lutein,intensity="normal",ccov=~suck,torder=1,
	interaction=1,dep="frailty",preg=c(1,0,0,0),psh=0.16,pdep=0.4,
	transform="log",envir=reps))
kalseries(lutein,intensity="logistic",ccov=~suck,torder=1,
	interaction=1,dep="frailty",preg=c(1,0,0,0),psh=0.16,pdep=0.4,
	transform="log",envir=reps)
kalseries(lutein,intensity="Cauchy",ccov=~suck,torder=1,
	interaction=1,dep="frailty",preg=c(6.3,-0.2,0.06,-0.4),psh=0.17,
	pdep=0.46,transform="log",envir=reps)
kalseries(lutein,intensity="Weibull",ccov=~suck,torder=1,
	interaction=1,dep="frailty",preg=c(100,0,0,0),psh=0.16,pdep=0.4,
	envir=reps)
kalseries(lutein,intensity="gamma",ccov=~suck,torder=1,
	interaction=1,dep="frailty",preg=c(100,0,0,0),psh=0.16,pdep=0.4,
	envir=reps)

if(interactive()){
postscript("lutein8.eps",height=5)
par(mfcol=c(1,2),font.main=1,mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0),font.main=1)
plot(iprofile(zknarf),nind=1:2,xlim=c(0,10),ylim=c(0,2000),pch=0:1,lty=2:3,
	main="Nonsuckled cows",xlab="Days",ylab="Luteinizing hormone")
plot(mprofile(zknarf),nind=1,add=T)
legend(0,1500,legend=c("Marginal profile","Cow 1","Cow 2"),bty="n",
	lty=1:3,pch=-1:1)
plot(iprofile(zknarf),nind=17:18,xlim=c(0,10),ylim=c(0,2000),pch=0:1,lty=2:3,
	main="Suckled cows",xlab="Days",ylab="")
plot(mprofile(zknarf),nind=18,add=T)
legend(0,1500,legend=c("Marginal profile","Cow 17","Cow 18"),bty="n",
	lty=1:3,pch=-1:1)
dev.off()
}
