library(growth)

data <- read.table("transistor.dat",skip=2,head=T)
attach(data)
Hours <- Hours/1000
dh <- diff(Hours)
dg <- diff(Gain)

psi <- matrix(0,ncol=30,nrow=30)
psi[cbind(1:29,2:30)] <- -1
psi[cbind(2:30,1:29)] <- -1
like <- function(p){
	time <- diff(1-exp(-p[2]*Hours))
	diag(psi) <- exp(p[1])*time+2
	invpsi <- solve(psi)
	delta <- (time%*%invpsi%*%dg)/(time%*%invpsi%*%time)
	sigma2 <- dg-delta*time
	sigma2 <- (sigma2%*%invpsi%*%sigma2)/30
	15*(1+log(2*pi*sigma2))+log(det(psi))/2+
		log(2*pi*sigma2)/2+(Gain[1]-p[3])^2/(2*sigma2)}

print(mdl <- nlm(like,p=c(0.1,0.01,90)))
p <- mdl$estimate
time <- diff(1-exp(-p[2]*Hours))
diag(psi) <- exp(p[1])*time+2
invpsi <- solve(psi)
print(delta <- (time%*%invpsi%*%dg)/(time%*%invpsi%*%time))
sigma2 <- dg-delta*time
print(sigma2 <- (sigma2%*%invpsi%*%sigma2)/30)

like2 <- function(p){
	time <- diff(1-exp(-p[2]*Hours^p[3]))
	diag(psi) <- exp(p[1])*time+2
	invpsi <- solve(psi)
	delta <- (time%*%invpsi%*%dg)/(time%*%invpsi%*%time)
	sigma2 <- dg-delta*time
	sigma2 <- (sigma2%*%invpsi%*%sigma2)/30
	15*(1+log(2*pi*sigma2))+log(det(psi))/2+
		log(2*pi*sigma2)/2+(Gain[1]-p[4])^2/(2*sigma2)}

print(mdl2 <- nlm(like2,p=c(0.1,0.01,1,90)))
p2 <- mdl2$estimate
time2 <- diff(1-exp(-p2[2]*Hours^p2[3]))
diag(psi) <- exp(p2[1])*time2+2
invpsi <- solve(psi)
print(delta2 <- (time2%*%invpsi%*%dg)/(time2%*%invpsi%*%time2))
sigma22 <- dg-delta2*time2
print(sigma22 <- (sigma22%*%invpsi%*%sigma22)/30)

print(mdl3 <- elliptic(Gain,times=Hours,
	model=~alpha+delt*(1-exp(-lambda*Hours)),preg=c(90,-8,0.3)))
print(mdl4 <- elliptic(Gain,times=Hours,par=0.1,
	model=~alpha+delt*(1-exp(-lambda*Hours)),preg=c(90,-8,0.3)))
print(mdl5 <- elliptic(Gain,times=Hours,
	model=~alpha+delt*(1-exp(-lambda*Hours^kappa)),preg=c(90,-8,0.3,1)))
print(mdl6 <- elliptic(Gain,times=Hours,par=0.1,
	model=~alpha+delt*(1-exp(-lambda*Hours^kappa)),preg=c(90,-8,0.3,1)))

if(interactive()){
postscript("transistor.eps",width=5,height=5)
par(mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(Hours*1000,Gain,pch=20,xlab="Hours")
lines(Hours*1000,p[3]+delta*(1-exp(-p[2]*Hours)))
lines(Hours*1000,p2[4]+delta2*(1-exp(-p2[2]*Hours^p2[3])),lty=2)
lines(Hours*1000,fitted(mdl6),lty=3)
legend(1500,91,legend=c("Diffusion",
	expression(~~alpha+delta(1-exp(-lambda*Hours/1000))),
	expression(~~alpha+delta(1-exp(-lambda*(Hours/1000)^kappa))),"AR(1)",
	expression(~~alpha+delta(1-exp(-lambda*(Hours/1000)^kappa)))),
	lty=c(0:2,0,3),bty="n")
dev.off()
}

print(mdl7 <- elliptic(Gain,times=Hours,preg=c(80,8,0.3),
	model=~alpha0+alpha1*exp(-alpha2*Hours)))
print(mdl8 <- elliptic(Gain,times=Hours,preg=c(82.8,8.08,0.3,1,0.01),
	model=~alpha+delt*exp(-lambda*Hours),
	varfn=~sigma+log(1+(sigma0-1)*exp(-2*lambda*Hours))-log(2*lambda),
	common=T))
exp(mdl8$coef[4])
mdl8$coef[5]*exp(mdl8$coef[4])/(2*mdl8$coef[3])
print(mdl9 <- elliptic(Gain,times=Hours,preg=c(91,-12,0.3,0.73,1,0.01),
	model=~alpha+delt*(1-exp(-lambda*Hours^kappa)),
	varfn=~sigma+log(1+(sigma0-1)*exp(-2*lambda*Hours))-log(2*lambda),
	common=T))
exp(mdl9$coef[5])
mdl9$coef[6]*exp(mdl9$coef[5])/(2*mdl9$coef[3])
print(mdl10 <- elliptic(Gain,times=Hours,preg=c(91,-9,0.32,0.8,-2.6,0.14),
	model=~alpha+delt*(1-exp(-lambda*Hours^kappa)),
	varfn=~sigma+log(1+(sigma0-1)*exp(-2*lambda*Hours))-log(2*lambda),
	par=0.25,common=T,iter=200))

if(interactive()){
postscript("transistor2.eps",width=5,height=5)
par(mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(Hours*1000,Gain,pch=20,xlab="Hours")
lines(Hours*1000,p2[4]+delta2*(1-exp(-p2[2]*Hours^p2[3])),lty=2)
lines(Hours*1000,fitted(mdl6),lty=3)
lines(Hours*1000,fitted(mdl8))
lines(Hours*1000,fitted(mdl9),lty=4)
legend(1500,91,legend=c("Diffusion","AR(1)","Ornstein-Uhlenbeck",
	expression(~~kappa==1),expression(~~kappa==0.815)),
	lty=c(2,3,0,1,4),bty="n")
dev.off()
}

like8a <- function(p){
	mu <- p[1]+p[2]*exp(-p[3]*Hours)
	psi <- p[5]/(2*p[3])+(p[4]-p[5]/(2*p[3]))*exp(-2*p[3]*Hours)
	(31*log(2*pi)+sum(log(psi))+(Gain-mu)%*%diag(1/psi)%*%(Gain-mu))/2}

print(mdl8a <- nlm(like8a,p=c(82,8.3,0.33,0.016,0.072)))

# gives nonsense results
#like11 <- function(p){
#	mu <- p[1]+p[2]*exp(-p[3]*Hours)
#	psi <- diag(p[5]/(2*p[3])+(p[4]-p[5]/(2*p[3]))*exp(-2*p[3]*Hours))
#	for(i in 1:30)for(j in (i+1):31)psi[i,j] <- psi[j,i] <-
#		(p[5]/(2*p[3]))*exp(-p[3]*(Hours[j]-Hours[i]))+
#		(p[4]-p[5]/(2*p[3]))*exp(-p[3]*(Hours[i]+Hours[j]))
#	(log(det(psi))+(Gain-mu)%*%solve(psi)%*%(Gain-mu))/2}

#print(mdl11 <- nlm(like11,p=c(82.2,8.3,0.33,0.035,0.071),print=2))
#mdl11$min+31*log(2*pi)
