library(gnlm)
library(repeated)

y <- scan("aids.dat",skip=4)
times <- 1:64
mue <- ~a*exp(b*times)
mul <- ~a/(1+c*exp(-b*times))
mucll <- ~a*(1-exp(-c*exp(-b*times)))
mull <- ~a*exp(-c*exp(-b*times))

print(zpe <- gnlr(y,mu=mue,pmu=c(1,0.05),dist="Poisson"))
print(zpl <- gnlr(y,mu=mul,pmu=c(50,100,0.1),dist="Poisson"))
print(zpcll <- gnlr(y,mu=mucll,pmu=c(50,0.1,0.05),dist="Poisson"))
print(zpll <- gnlr(y,mu=mull,pmu=c(100,5,0.05),dist="Poisson"))

print(zpeq <- gnlr(y,mu=~a*exp(b*times+c*times^2),pmu=c(0.26,0.1,-0.01),
	dist="Poisson"))
D(expression(a*exp(b*times+c*times^2)),"times")
-zpeq$coef[2]/(2*zpeq$coef[3])

print(znbe <- gnlr(y,mu=mue,pmu=c(1,0.05),psh=1,dist="negative binomial"))
print(znbl <- gnlr(y,mu=mul,pmu=c(50,100,0.1),psh=1,dist="negative binomial"))
print(znbcll <- gnlr(y,mu=mucll,pmu=c(50,0.1,0.1),psh=10,
	dist="negative binomial"))
print(znbll <- gnlr(y,mu=mull,pmu=c(100,5,0.05),psh=1,
	dist="negative binomial"))

print(upe <- gar(y,times=times,mu=mue,preg=c(1,0.05),pdep=0.01,dist="Poisson"))
print(upl <- gar(y,times=times,mu=mul,preg=c(50,100,0.1),pdep=0.1,
	dist="Poisson"))
print(upcll <- gar(y,times=times,mu=mucll,preg=c(40,0.01,-0.1),pdep=0.1,
	dist="Poisson"))
print(upll <- gar(y,times=times,mu=mull,preg=c(50,5,0.05),pdep=0.1,
	dist="Poisson"))

if(interactive()){
postscript(file="aids.eps",height=5,width=5)
par(mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(times,y,pch=20,xlab="Month",ylab="AIDS cases")
lines(times,zpe$fitted)
lines(times,zpl$fitted,lty=2)
lines(times,zpcll$fitted,lty=3)
lines(times,zpll$fitted,lty=4)
legend(0,45,lty=1:4,bty="n",
	legend=c("Exponential","Logistic","Gompertz","Complementary Gompertz"))
dev.off()
}
