library(growth)

y <- scan("bean.dat",skip=3)
reps <- rmna(restovec(y,times=17:52))

# monomolecular
print(zn <- elliptic(y,model=~a-b*exp(-c*times),preg=c(60,100,0.03),
	pvar=6,env=reps))
print(znar <- elliptic(y,model=~a-b*exp(-c*times),preg=c(60,113,0.034),
	pvar=1.7,par=0.1,env=reps))
print(zln <- elliptic(y,model=~a-b*exp(-c*times),preg=c(35,34,0.01),
	transform="log",pvar=1,env=reps))
print(zlnar <- elliptic(y,model=~a-b*exp(-c*times),preg=c(4,30,0.1),
	transform="log",pvar=0.1,par=0.1,env=reps))
print(znar2 <- elliptic(y,model=~exp(a-b*exp(-c*times)),preg=c(1,20,0.1),
	pvar=2,par=0.1,env=reps))

if(interactive()){
postscript(file="bean.eps",height=5)
par(mfrow=c(1,2),mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0),font.main=1)
plot(mprofile(znar),xlab="Day",ylab="Area",xlim=c(-5,55),ylim=c(0,40))
plot(iprofile(znar),add=T,pch=20,lty=2)
plot(mprofile(zlnar),add=T,lty=3)
plot(iprofile(zlnar),add=T,pch=20,lty=4)
legend(-6,42,legend=c("Observed","Log normal profile","Log normal prediction",
	"Normal profile","Normal prediction"),lty=c(0,3,4,1,2),
	pch=c(20,-1,-1,-1,-1),bty="n")
plot(mprofile(znar2),xlab="Day",ylab="",xlim=c(-5,55),ylim=c(0,40))
plot(iprofile(znar2),add=T,pch=20,lty=2)
plot(mprofile(zlnar),add=T,lty=3)
plot(iprofile(zlnar),add=T,pch=20,lty=4)
dev.off()
}

# Richards
print(znr <- elliptic(y,model=~a*(1+((a/d)^b-1)*exp(-c*times))^(-1/b),
	preg=c(37.17,0.0079,0.734,0.217),pvar=0.195,env=reps))
print(znrar <- elliptic(y,model=~a*(1+((a/d)^b-1)*exp(-c*times))^(-1/b),
	preg=c(37.17,0.0078,0.733,0.217),pvar=0.195,par=0.8,env=reps))

if(interactive()){
postscript(file="bean2.eps",height=5,width=5)
par(mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0),font.main=1)
plot(mprofile(znrar),xlab="Day",ylab="Area",xlim=c(-5,55),ylim=c(0,40))
plot(iprofile(znrar),add=T,pch=20,lty=2)
legend(0,35,legend=c("Observed","Normal profile","Normal prediction",),
	lty=0:2,pch=c(20,-1,-1),bty="n")
dev.off()
}
