library(growth)

y <- scan("capital.dat",skip=2)
times <- 1948:1967

# log normal
glm(log(y)~I(times-1957.5))
print(zln <- carma(y,times=times,transform="log",torder=1))
exp(zln$beta[1])
exp(zln$beta[1]+zln$beta[2]*(1968-1957.5))
exp(zln$beta[1]+zln$beta[2]*(1968-1957.5)+zln$mse/2)

print(zlnar <- carma(y,times=times,transform="log",torder=1,
	arma=1,parma=0.5))
exp(zlnar$beta[1])
exp(zlnar$beta[1]+zlnar$beta[2]*(1968-1957.5))
exp(zlnar$beta[1]+zlnar$beta[2]*(1968-1957.5)+zlnar$mse/2)
exp(zlnar$rpred[20])
exp(zlnar$pred[20]+exp(-exp(zlnar$coef))*(log(y[19])-zlnar$pred[19]))
exp(zlnar$beta[1]+zlnar$beta[2]*(1968-1957.5)+
	exp(-exp(zlnar$coef))*(log(y[20])-zlnar$pred[20]))
exp(zlnar$beta[1]+zlnar$beta[2]*(1968-1957.5)+
	exp(-exp(zlnar$coef))*(log(y[20])-zlnar$pred[20])+zlnar$mse/2)

# normal
print(zn <- glm(y~I(times-1957.5),family=gaussian(link=log)))
zn$aic/2
exp(zn$coef[1])
exp(zn$coef[1]+zn$coef[2]*(1968-1957.5))

elliptic(y,times=times,model=~a*exp(b*(times-1957.5)),preg=c(1400,0.08))
print(znar <- elliptic(y,times=times,model=~a*exp(b*(times-1957.5)),
	preg=c(1400,0.08),par=0.1))
znar$coef[1]
znar$coef[1]*exp(znar$coef[2]*(1968-1957.5))
znar$rpred[20]
znar$pred[20]+znar$rho*(y[19]-znar$pred[19])
znar$coef[1]*exp(znar$coef[2]*(1968-1957.5))+znar$rho*(y[20]-znar$pred[20])

if(interactive()){
postscript(file="capital.eps",height=5)
par(mfrow=c(1,2),mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0),font.main=1)
plot(iprofile(zlnar),lty=2,pch=20,ylim=c(0,8000),main="Log normal",xlab="Year",
	ylab="Capital formation")
plot(mprofile(zlnar,plotse=F),add=T)
legend(1947,7000,lty=1:2,bty="n",
	legend=c("Marginal curve","Recursive prediction"))

plot(iprofile(znar),lty=2,pch=20,main="Normal",ylim=c(0,8000),xlab="Year",
	ylab="")
plot(mprofile(znar),add=T)
dev.off()
}
