library(gnlm)
library(repeated)

data <- read.table("sulphate.dat",skip=3,head=T)
attach(data)
y <- c(Comp1,Comp2)

mu <- function(p){
	i <- 0
	p <- exp(p)
	V <- matrix(c(-p[1]-p[3],p[2],0,p[1],-p[2]-p[4],0,p[3],p[4],
		-p[3]-p[4]),ncol=3)
	ret <- matrix(0,nrow=length(Time),ncol=2)
	for(i in 1:length(Time)){
		tmp <- mexp(V,Time[i])
		ret[i,] <- tmp[1,1:2]}
	as.vector(ret)}

mu2 <- function(p){
	i <- 0
	p <- exp(p)
	V <- matrix(c(-p[1]-p[3],p[2],0,p[1],-p[2],0,p[3],0,
		-p[3]),ncol=3)
	ret <- matrix(0,nrow=length(Time),ncol=2)
	for(i in 1:length(Time)){
		tmp <- mexp(V,Time[i])
		ret[i,] <- tmp[1,1:2]}
	as.vector(ret)}

lmu <- function(p){
	i <- 0
	p <- exp(p)
	V <- matrix(c(-p[1]-p[3],p[2],0,p[1],-p[2]-p[4],0,p[3],p[4],
		-p[3]-p[4]),ncol=3)
	ret <- matrix(0,nrow=length(Time),ncol=2)
	for(i in 1:length(Time)){
		tmp <- mexp(V,Time[i])
		ret[i,] <- tmp[1,1:2]}
	log(as.vector(ret))}

lmu2 <- function(p){
	i <- 0
	p <- exp(p)
	V <- matrix(c(-p[1]-p[3],p[2],0,p[1],-p[2],0,p[3],0,
		-p[3]),ncol=3)
	ret <- matrix(0,nrow=length(Time),ncol=2)
	for(i in 1:length(Time)){
		tmp <- mexp(V,Time[i])
		ret[i,] <- tmp[1,1:2]}
	log(as.vector(ret))}

print(zn1 <- gnlr(y,mu=mu,pmu=log(c(0.03,0.023,0.045,0.001)),dist="normal",
	psh=-6.8,delta=0.01))
print(zn2 <- gnlr(y,mu=mu2,pmu=log(c(0.027,0.019,0.046)),dist="normal",
	psh=-6.8,delta=0.01))
print(znar2 <- gar(y,mu=mu2,preg=log(c(0.027,0.019,0.046)),dist="normal",
	psh=exp(-6.8),pdep=0.1,delta=0.01))

print(zln1 <- gnlr(log(y),mu=lmu,pmu=log(c(0.03,0.023,0.045,0.001)),
	dist="normal",psh=-3.7,delta=0.01/y))
print(zln2 <- gnlr(log(y),mu=lmu2,pmu=log(c(0.027,0.02,0.041)),dist="normal",
	psh=-3.7,delta=0.01/y))

print(zg1 <- gnlr(y,mu=mu,pmu=log(c(0.03,0.023,0.045,0.001)),dist="gamma",
	psh=3.7,delta=0.01))
print(zg2 <- gnlr(y,mu=mu2,pmu=log(c(0.028,0.02,0.041)),dist="gamma",
	psh=3.7,delta=0.01))

print(zb1 <- gnlr(y,mu=mu,pmu=log(c(0.03,0.023,0.045,0.001)),dist="beta",
	psh=-1,delta=0.01))
print(zb2 <- gnlr(y,mu=mu2,pmu=log(c(0.029,0.022,0.044)),dist="beta",
	psh=5,delta=0.01))

print(zs1 <- gnlr(y,mu=mu,pmu=log(c(0.03,0.023,0.045,0.001)),dist="simplex",
	psh=-1,delta=0.01))
print(zs2 <- gnlr(y,mu=mu2,pmu=log(c(0.03,0.022,0.043)),dist="simplex",
	psh=-1,delta=0.01))
exp(zs2$coef[1:3])

if(interactive()){
postscript("compart3.eps",height=3)
par(mar=c(0,0,0,0),mgp=c(2.5,1,0))
plot(c(0, 100), c(0, 100), type="n",axes=F,ylab="",xlab="")
arrows(27,100,27,90,length=0.15)
text(33,97,"Injection")
rect(10,10,45,90)
text(27,50,"1")
arrows(45,30,55,30,length=0.15)
text(50,32,expression(k[12]))
arrows(55,70,45,70,length=0.15)
text(50,72,expression(k[21]))
rect(55,10,90,90)
text(72,50,"2")
arrows(27,10,27,0,length=0.15)
text(30,2,expression(k[1][e]))
arrows(72,10,72,0,length=0.15)
text(75,2,expression(k[2][e]))
dev.off()

postscript("sulphate.eps",width=5,height=5)
par(mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(Time,Comp1,pch=1,xlab="Hours",ylab="Proportion")
lines(Time,Comp1,lty=3)
points(Time,Comp2,pch=2)
lines(Time,Comp2,lty=3)
lines(Time,zs2$fit[1:8])
lines(Time,zs2$fit[9:16],lty=2)
legend(40,0.8,legend=c("Compartment 1","  Observed","  Fitted",
	"Compartment 2","  Observed","  Fitted"),lty=c(0,3,1,0,3,2),
	pch=c(-1,1,-1,-1,2,-1),bty="n")
dev.off()
}
