library(growth)

level <- read.table("bloodsug.dat",skip=6,head=T)
times <- c(0,1.5,3,4.5,6)
treat <- c(rep(c(0,1),22),rep(c(1,0),22))
period <- as.factor(c(rep(c(1,2,3,4),22)))
group <- gl(2,44,88)
per4 <- period==4
y <- restovec(matrix(t(as.matrix(level)),ncol=20,byrow=T),times=rep(times,4),
	nest=rep(1:4,rep(5,4)))
level <- rmna(restovec(level,times=times),
	ccov=tcctomat(data.frame(group,per4,treat,period)))

if(interactive()){
postscript("bloodsug.eps",height=5)
par(mfrow=c(1,2),font.main=1,mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(level,nind=seq(1,41,by=4),ylim=c(0,140),xlab="Hours after injection",
	ylab="Blood sugar level",main="Treatment A",lty=4,xaxt="n",yaxt="n")
axis(1,at=c(0,1.5,3,4.5,6))
axis(2,at=c(0,40,80,120))
plot(level,nind=seq(3,43,by=4),lty=3,add=T)
plot(level,nind=seq(46,86,by=4),lty=2,add=T)
plot(level,nind=seq(48,88,by=4),lty=1,add=T)
legend(0.5,145,legend=c("Period 1","Period 2","Period 3","Period 4"),
	lty=1:4,bty="n")
plot(level,nind=seq(2,42,by=4),ylim=c(0,140),xlab="Hours after injection",
	ylab="",main="Treatment B",lty=2,xaxt="n",yaxt="n")
axis(1,at=c(0,1.5,3,4.5,6))
axis(2,at=c(0,40,80,120))
plot(level,nind=seq(4,44,by=4),lty=1,add=T)
plot(level,nind=seq(45,85,by=4),lty=4,add=T)
plot(level,nind=seq(47,87,by=4),lty=3,add=T)
legend(1,145,legend=c("Period 1","Period 2","Period 3","Period 4"),
	lty=1:4,bty="n")
dev.off()
}

carma(level,ccov=~treat+group+period,torder=2)
carma(level,ccov=~treat+group+period,torder=2,int=rep(2,5))
carma(level,ccov=~treat+group+per4,torder=2,inter=c(1,2,1))

tvc <- list()
for(i in 1:11) tvc <- c(tvc,list(cbind(rep(times-3,4),
	rep(c(rep(0,5),rep(1,5)),2),c(rep(0,15),rep(1,5)))))
for(i in 1:11) tvc <- c(tvc,list(cbind(rep(times-3,4),
	rep(c(rep(1,5),rep(0,5)),2),c(rep(0,15),rep(1,5)))))
tvc <- tvctomat(tvc,names=c("t","trt","per4"))
tvc <- tvctomat(tvc,interact=c("trt","t"))
tvc <- tvctomat(tvc,interact=c("per4","t"))
grp <- gl(2,11,22)
reps <- rmna(y,ccov=tcctomat(~grp),tvcov=tvc)

elliptic(reps,ccov=~grp2,int=2,tvcov=~trt+trt.t+per4+per4.t,
	torder=2,pvar=251,par=0.425,pre=c(47,0.01))
elliptic(reps,ccov=~grp2,int=2,tvcov=~trt+trt.t+per4+per4.t,
	torder=2,pvar=251.6,par=0.426,pre=45.37)

# variance depending on time
elliptic(reps,ccov=~grp2,int=2,tvcov=~trt+trt.t+per4+per4.t,
	torder=2,pvar=c(5.5,0),par=0.436,pre=45.37,varfn=~t,iter=200,
	preg=c(39.5,-2.7,4.6,-6.6,1.8,1.1,1.2,1.5,15.4,1.3))
print(z <- elliptic(reps,ccov=~grp2,int=2,tvcov=~per4,torder=2,
	pvar=c(5.6,0),par=0.443,pre=45.37,varfn=~t,
	preg=c(40.1,-2.4,4.6,-6.6,1.5,1.1,15.4)))
elliptic(reps,ccov=~grp2,int=2,torder=2,pvar=c(5.5,0),pre=45.37,
	varfn=~t,preg=c(44,-1.2,4.6,-6.6,1.9,1.1))
elliptic(reps,tvcov=~per4+per4.t,torder=2,pvar=c(5.5,0),
	pre=45.37,varfn=~t,preg=c(36.7,-0.7,5.1,15.7,1.6))

if(interactive()){
pl <- function(p,t) p[1]+p[2]*(t-3)+p[3]*(t-3)^2+p[4]*grp+
	p[5]*grp*(t-3)+p[6]*grp*(t-3)^2+p[9]*per+p[10]*per*(t-3)+
	p[7]*trt+p[8]*(t-3)*trt
postscript("bldsugpr.eps",height=5,width=5)
par(font.main=1,mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
grp <- per <- trt <- 0
plot(mprofile(z,mu=pl,times=c(0,1.5,3,4.5,6)),ylim=c(0,140),
	xlab="Hours after injection",ylab="Blood sugar level",
	lty=4,xaxt="n",yaxt="n")
axis(1,at=c(0,1.5,3,4.5,6))
axis(2,at=c(0,40,80,120))
per <- 1
plot(mprofile(z,mu=pl,times=c(0,1.5,3,4.5,6)),add=T,lty=1)
grp <- 1
per <- 0
plot(mprofile(z,mu=pl,times=c(0,1.5,3,4.5,6)),add=T,lty=2)
per <- 1
plot(mprofile(z,mu=pl,times=c(0,1.5,3,4.5,6)),add=T,lty=3)
legend(0,150,legend=c("Periods 1-3, Group 1","Period 4,       Group 1",
	"Periods 1-3, Group 2","Period 4,       Group 2"),lty=c(4,1:3),bty="n")
dev.off()
}
