library(gnlm)

data <- read.table("divorce.dat",skip=4,header=T)
attach(data)

mean(LM,na.rm=T)
var(LM,na.rm=T)
sd(LM,na.rm=T)
mean(HA)
mean(WA)

if(interactive()){
postscript(file="divorce0.eps")
par(mfrow=c(2,2),mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0),font.main=1)
hist(LM,xlab="",ylab="Proportion of divorces",prob=T,ylim=c(0,0.065),
	main="All couples")
box()
hist(LM[Applicant==1],xlab="",ylab="",prob=T,ylim=c(0,0.065),
	main="Husband applicant")
box()
hist(LM[Applicant==2],xlab="Length of marriage",ylab="Proportion of divorces",
	prob=T,xlim=c(0,55),ylim=c(0,0.065),main="Wife applicant")
box()
hist(LM[Applicant==3],xlab="Length of marriage",ylab="",prob=T,xlim=c(0,55),
	ylim=c(0,0.065),main="Mutual agreement")
box()
dev.off()

#postscript(file="divorce1.eps",height=5,width=5)
#par(mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
#plot(HA,LM,pch=20,xlab="Husband's age",ylab="Length of marriage")
#dev.off()
}

print(z1 <- summary(glm(LM~HA)))
z1$aic/2
print(z0 <- summary(glm(LM~1)))
z0$aic/2
print(z2 <- summary(glm(LM~HA+I(HA^2))))
z2$aic/2

if(interactive()){
age <- 20:85
postscript(file="divorce1.eps",height=5,width=5)
par(mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(HA,LM,pch=20,xlab="Husband's age",ylab="Length of marriage")
abline(coef(z1)[1],coef(z1)[2])
lines(age,coef(z2)[1]+coef(z2)[2]*age+coef(z2)[3]*age^2,lty=2)
legend(20,54,legend=c("Linear","Quadratic"),lty=1:2,bty="n")
dev.off()
}

print(z1f <- summary(glm(LM~WA)))
z1f$aic/2
print(z2f <- summary(glm(LM~WA+I(WA^2))))
z2f$aic/2
print(z3 <- summary(glm(LM~HA+I(HA^2)+WA+I(WA^2))))
z3$aic/2
print(z3a <- summary(glm(LM~HA+I(HA^2)+WA)))
z3a$aic/2
print(z3b <- summary(glm(LM~HA+I(HA^2)+WA+HA:WA)))
z3b$aic/2
print(z3c <- summary(glm(LM~HA+WA+I(HA^2)+I(WA^2)+HA:WA)))
z3c$aic/2
print(z3d <- summary(glm(LM~HA+I(HA^2)+WA+HA:WA+I(HA^2):WA)))
z3d$aic/2
print(z3e <- summary(glm(LM~HA+I(HA^2)+I(WA^2)+WA+HA:WA+I(HA^2):WA)))
z3e$aic/2
print(z3f <- summary(glm(LM~HA+I(HA^2)+I(WA^2)+WA+HA:WA+I(HA^2):WA+
	I(WA^2):HA)))
z3f$aic/2
print(z3g <- summary(glm(LM~HA+WA+I(HA^2)+I(WA^2)+HA:WA+I(HA^2):WA+
	I(HA^3))))
z3g$aic/2
print(z3h <- summary(glm(LM~HA+WA+I(HA^2)+I(WA^2)+HA:WA+I(HA^2):WA+
	I(WA^3))))
z3h$aic/2
print(z3i <- summary(glm(LM~HA+WA+I(HA^2)+I(WA^2)+HA:WA+I(HA^3))))
z3i$aic/2

if(interactive()){
postscript(file="divorce2.eps",height=5)
par(mfrow=c(1,2),mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
age <- seq(5,85,by=5)
fn <- function(ha,wa,coef)coef[1]+coef[2]*ha+coef[3]*wa+coef[4]*ha^2+
	coef[5]*wa^2+coef[6]*ha^3+coef[7]*ha*wa
contour(age,age,matrix(fn(rep(age,17),rep(age,rep(17,17)),z3i$coef),ncol=17),
	levels=seq(0,40,by=5),xlab="Husband's Age",ylab="Wife's Age",
	labcex=0.6,xlim=c(20,85),ylim=c(20,85))
fn <- function(ha,wa,coef){
	tmp <- coef[1]+coef[2]*ha+coef[3]*wa+coef[4]*ha^2+
		coef[5]*wa^2+coef[6]*ha^3+coef[7]*ha*wa
	ifelse(tmp>0,tmp,NA)}
persp(age,age,matrix(fn(rep(age,17),rep(age,rep(17,17)),z3i$coef),ncol=17),
	phi=25,theta=-45,r=20,xlab="Husband's Age",ylab="Wife's Age",
	zlab="Length of Marriage",tick="detail",cex=0.7,zlim=c(0,40),
	xlim=c(20,85),ylim=c(20,85))
dev.off()
}

applicant <- factor(Applicant,labels=c("Husband","Wife","Mutual"))
tapply(LM,applicant,mean,na.rm=T)

options(contrasts = c("contr.treatment", "contr.poly"))
print(z4 <- summary(glm(LM~applicant)))
z4$aic/2
options(contrasts = c("contr.mean", "contr.poly"))
print(z4a <- summary(glm(LM~applicant)))
z4a$aic/2
-(2.6386-0.1368)

options(contrasts = c("contr.treatment", "contr.poly"))
print(z5 <- summary(glm(LM~HA+I(HA^2)+WA+applicant)))
z5$aic/2
print(z6 <- summary(glm(LM~HA+I(HA^2)+applicant)))
z6$aic/2
print(z7 <- summary(glm(LM~(HA+I(HA^2)+WA)*applicant)))
z7$aic/2
print(z8 <- summary(glm(LM~(HA+I(HA^2))*applicant)))
z8$aic/2
print(z8a <- summary(glm(LM~HA*applicant+I(HA^2))))
z8a$aic/2
if(interactive()){
age <- 20:85
postscript(file="divorce3.eps",height=5)
par(mfrow=c(1,2),mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(age,coef(z6)[1]+coef(z6)[2]*age+coef(z6)[3]*age^2,type="l",
	xlab="Husband's age",ylab="Length of marriage")
lines(age,coef(z6)[1]+coef(z6)[4]+coef(z6)[2]*age+coef(z6)[3]*age^2,lty=2)
lines(age,coef(z6)[1]+coef(z6)[5]+coef(z6)[2]*age+coef(z6)[3]*age^2,lty=3)
plot(age,coef(z8)[1]+coef(z8)[2]*age+coef(z8)[3]*age^2,type="l",
	xlab="Husband's age",ylab="")
lines(age,coef(z8)[1]+coef(z8)[4]+(coef(z8)[2]+coef(z8)[6])*age+
	(coef(z8)[3]+coef(z8)[8])*age^2,lty=2)
lines(age,coef(z8)[1]+coef(z8)[5]+(coef(z8)[2]+coef(z8)[7])*age+
	(coef(z8)[3]+coef(z8)[9])*age^2,lty=3)
legend(20,40,legend=c("Husband","Wife","Mutual"),lty=1:3,bty="n")
dev.off()
}
print(z8b <- summary(glm(LM~(HA+I(HA^2)+I(WA^2)+WA+HA:WA+I(HA^2):WA)*
	applicant)))
z8b$aic/2
print(z8c <- summary(glm(LM~HA+I(HA^2)+I(WA^2)+WA+HA:WA+I(HA^2):WA+
	(HA+WA+I(HA^2)+I(WA^2))*applicant)))
z8c$aic/2

print(z9 <- summary(glm(LM~HA+I(HA^2),family=Gamma)))
z9$aic/2
print(z10 <- summary(glm(LM~HA+I(HA^2),family=Gamma(link="identity"))))
z10$aic/2
if(interactive()){
age <- 20:85
postscript(file="divorce4.eps",height=5,width=5)
par(mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(HA,LM,pch=20,xlab="Husband's age",ylab="Length of marriage")
lines(age,1/(coef(z9)[1]+coef(z9)[2]*age+coef(z9)[3]*age^2))
lines(age,coef(z10)[1]+coef(z10)[2]*age+coef(z10)[3]*age^2,lty=2)
lines(age,coef(z2)[1]+coef(z2)[2]*age+coef(z2)[3]*age^2,lty=3)
legend(20,54,legend=c("Gamma with inverse link","Gamma with identity link",
	"Normal with identity link"),lty=1:3,bty="n")
dev.off()
}
print(z11 <- summary(glm(LM~HA+I(HA^2),family=gaussian(link="inverse"))))
z11$aic/2

#obtain exact AIC for gamma distribution
reps <- rmna(restovec(LM),tcctomat(HA))
reps <- transform(reps,LLM=log(LM))
gnlr(LM,mu=~1/(b0+b1*HA+b2*HA^2),dist="gamma",pmu=z9$coef[1:3],psh=2.1,
	envir=reps)
gnlr(LM,mu=~HA+I(HA^2),dist="gamma",pmu=z10$coef[1:3],psh=2.1,envir=reps)

# other distributions
print(zw <- gnlr(LM,mu=~HA+I(HA^2),dist="Weibull",pmu=z10$coef[1:3],psh=2.1,
	envir=reps))
gnlr(LM,mu=~1,dist="gamma",pmu=14,psh=2.1,envir=reps)
gnlr(LM,mu=~1,dist="Weibull",pmu=14,psh=2.1,envir=reps)

if(interactive()){
age <- 20:85
postscript(file="divorce5.eps",height=5,width=5)
par(mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(HA,LM,pch=20,xlab="Husband's age",ylab="Length of marriage")
lines(age,coef(z10)[1]+coef(z10)[2]*age+coef(z10)[3]*age^2,lty=2)
lines(age,coef(zw)[1]+coef(zw)[2]*age+coef(zw)[3]*age^2)
legend(20,54,legend=c("Weibull","Gamma"),lty=1:2,bty="n")
dev.off()
}

print(z12 <- summary(glm(LM~HA+I(HA^2),
	family=inverse.gaussian(link="identity"))))
z12$aic/2
gnlr(LM,mu=~HA+I(HA^2),dist="inverse Gauss",pmu=z10$coef[1:3],psh=2.1,
	envir=reps)
gnlr(LLM,mu=~HA+I(HA^2),dist="normal",pmu=z10$coef[1:3],psh=2.1,envir=reps)
gnlr(LLM,mu=~HA+I(HA^2),dist="logistic",pmu=c(-1.6,0.16,-0.0013),psh=-3.7,
	envir=reps)
gnlr(LLM,mu=~HA+I(HA^2),dist="Cauchy",pmu=c(-1.6,0.16,-0.0013),psh=-3.7,
	envir=reps)
gnlr(LLM,mu=~HA+I(HA^2),dist="Laplace",pmu=c(-1.6,0.16,-0.0013),psh=-3.7,
	envir=reps)

# nonlinear models
print(zwl <- gnlr(LM,mu=~c/(1+exp(-(a+b*HA))),dist="Weibull",
	pmu=c(40,-4,0.1),psh=1.3,envir=reps))

if(interactive()){
age <- 20:85
postscript(file="divorce6.eps",height=5,width=5)
par(mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(HA,LM,pch=20,xlab="Husband's age",ylab="Length of marriage")
lines(age,coef(zw)[1]+coef(zw)[2]*age+coef(zw)[3]*age^2)
lines(age,coef(zwl)[1]/(1+exp(-(coef(zwl)[2]+coef(zwl)[3]*age))),lty=2)
legend(20,54,legend=c("Quadratic","Logistic"),lty=1:2,bty="n")
dev.off()
}
