library(gnlm)
library(event)

breast <- read.table("cosmesis.dat",skip=8)
names(breast) <- c("surv","delta","cens","treat")
attach(breast)

treat <- treat-1
for(i in 1:length(treat))if(surv[i]-delta[i]/2==0){
	surv[i] <- surv[i]+delta[i]/2
	cens[i] <- -1
	delta[i] <- 0}
lsurv <- log(surv)
y <- cbind(surv,cens)
ly <- cbind(lsurv,cens)
mu <- function(p,linear) exp(linear)

gnlr(y, "exponential", pmu=30, linear=~1, delta=delta,exact=T)
gnlr(y, "gamma", pmu=30,psh=0, mu=~1, delta=delta,exact=T)
gnlr(y, "Weibull", pmu=30,psh=0, mu=~1, delta=delta,exact=T)
gnlr(y, "inverse Gauss", pmu=30,psh=0, mu=~1, delta=delta,exact=T)
gnlr(ly, "normal", pmu=2.5,psh=0.2, mu=~1, delta=delta/surv,exact=T)
gnlr(ly, "logistic", pmu=2.5,psh=0.2, mu=~1, delta=delta/surv,exact=T)
gnlr(ly, "Cauchy", pmu=2.5,psh=0.2, mu=~1, delta=delta/surv,exact=T)
gnlr(ly, "Laplace", pmu=1,psh=2, mu=~1, delta=delta/surv,exact=T)

gnlr(y, "exponential", pmu=c(4,0), mu=mu, linear=~treat, delta=delta,exact=T)
gnlr(y, "gamma", pmu=c(3.5,0),psh=0, mu=mu, linear=~treat, delta=delta,exact=T)
gnlr(y, "Weibull", pmu=c(3.5,0),psh=0, mu=mu, linear=~treat,
	delta=delta,exact=T)
gnlr(y, "inverse Gauss", pmu=c(3.5,0),psh=0, mu=mu, linear=~treat,
	delta=delta,exact=T)
gnlr(ly, "normal", pmu=c(2.5,0),psh=0.2, linear=~treat, delta=delta/surv,
	exact=T)
gnlr(ly, "logistic", pmu=c(2.5,0),psh=0.2, linear=~treat, delta=delta/surv,
	exact=T)
gnlr(ly, "Cauchy", pmu=c(2.5,0),psh=0.2, linear=~treat, delta=delta/surv,
	exact=T)
gnlr(ly, "Laplace", pmu=c(1,0),psh=2, linear=~treat, delta=delta/surv,exact=T)

gnlr(y, "gamma", pmu=30,psh=c(0,0), linear=list(~1,~treat),
	delta=delta,exact=T)
gnlr(y, "Weibull", pmu=30,psh=c(0,0), linear=list(~1,~treat),
	delta=delta,exact=T)
gnlr(y, "inverse Gauss", pmu=30,psh=c(-3,0), linear=list(~1,~treat),
	delta=delta,exact=T)
gnlr(ly, "normal", pmu=2.5,psh=c(0.2,0), linear=list(~1,~treat),
	delta=delta/surv,exact=T)
gnlr(ly, "logistic", pmu=2.5,psh=c(0.2,0), linear=list(~1,~treat),
	delta=delta/surv,exact=T)
gnlr(ly, "Cauchy", pmu=2.5,psh=c(0.2,0), linear=list(~1,~treat),
	delta=delta/surv,exact=T)
gnlr(ly, "Laplace", pmu=1,psh=c(2,0), linear=list(~1,~treat),
	delta=delta/surv,exact=T)

print(zg <- gnlr(y, "gamma", pmu=c(3.5,0),psh=c(0,0), mu=mu,
	linear=list(~treat,~treat), delta=delta,exact=T))
print(zw <- gnlr(y, "Weibull", pmu=c(3.5,0),psh=c(0,0), mu=mu,
	linear=list(~treat,~treat), delta=delta,exact=T))
gnlr(y, "inverse Gauss", pmu=c(9,-6),psh=c(-3,0), mu=mu,
	linear=list(~treat,~treat), delta=delta,exact=T)
gnlr(ly, "normal", pmu=c(2.5,0),psh=c(0.2,0), linear=list(~treat,~treat),
	delta=delta/surv,exact=T)
print(zlg <- gnlr(ly, "logistic", pmu=c(2.5,0),psh=c(0.2,0),
	linear=list(~treat,~treat), delta=delta/surv,exact=T))
print(zc <- gnlr(ly, "Cauchy", pmu=c(2.5,0),psh=c(0.2,0),
	linear=list(~treat,~treat), delta=delta/surv,exact=T))
print(zl <- gnlr(ly, "Laplace", pmu=c(1,0),psh=c(2,0),
	linear=list(~treat,~treat), delta=delta/surv,exact=T))

t <- 1:50

dlog <- function(u,s) exp(-(pi*u/s/sqrt(3)))/s/(1+exp(-pi*u/s/sqrt(3)))^2*(pi/sqrt(3))
plog <- function(u,m,s) plogis(u,m,s*sqrt(3)/pi)
clg1 <- dlog(log(t)-zlg$coefficients[1]-zlg$coefficients[2],exp(zlg$coefficients[3]+zlg$coefficients[4]))/(1-plog(log(t),zlg$coefficients[1]+zlg$coefficients[2],exp(zlg$coefficients[3]+zlg$coefficients[4])))/t
clg2 <- dlog(log(t)-zlg$coefficients[1]+zlg$coefficients[2],exp(zlg$coefficients[3]-zlg$coefficients[4]))/(1-plog(log(t),zlg$coefficients[1]-zlg$coefficients[2],exp(zlg$coefficients[3]-zlg$coefficients[4])))/t

plp <- function(u){
	t <- exp(-abs(u))/2
	ifelse(u<0,t,1-t)}

if(interactive()){
postscript(file="cosmetic.eps",height=5,width=5)
par(mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(z <- km(surv,cens==1,group=treat),main="",xlab="Months",
	ylab="Probability of no cosmetic deterioration")
lines(t,1-plp((log(t)-zl$coefficients[1])/exp(zl$coefficients[3])),lty=1)
lines(t,1-plp((log(t)-zl$coefficients[1]-zl$coefficients[2])/
	exp(zl$coefficients[3]+zl$coefficients[4])),lty=2)
legend(0,0.2,legend=c("Radiotherapy","Radiotherapy + chemotherapy"),
	lty=1:2,bty="n")
dev.off()
}

t <- seq(0.5,50,by=0.5)
dlp <- function(u,s) exp(-abs(u)/s)/s/2
clp1 <- dlp((log(t)-zl$coefficients[1]-zl$coefficients[2]),exp(zl$coefficients[3]+zl$coefficients[4]))/(1-plp((log(t)-zl$coefficients[1]-zl$coefficients[2])/exp(zl$coefficients[3]+zl$coefficients[4])))/t
clp2 <- dlp((log(t)-zl$coefficients[1]+zl$coefficients[2]),exp(zl$coefficients[3]-zl$coefficients[4]))/(1-plp((log(t)-zl$coefficients[1]+zl$coefficients[2])/exp(zl$coefficients[3]-zl$coefficients[4])))/t

if(interactive()){
postscript(file="cosmh.eps",height=5,width=5)
par(mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(t,clp1,type="l",lty=1,xlab="Months",ylab="Intensity",ylim=c(0,0.1))
lines(t,clp2,lty=2)
lines(t,dgamma(t,exp(zg$coefficients[3]+zg$coefficients[4]),scale=
	exp(zg$coefficients[1]+zg$coefficients[2]-zg$coefficients[3]-
	zg$coefficients[4]))/(1-pgamma(t,exp(zg$coefficients[3]+
	zg$coefficients[4]),scale=exp(zg$coefficients[1]+zg$coefficients[2]-
	zg$coefficients[3]-zg$coefficients[4]))),lty=3)
lines(t,dgamma(t,exp(zg$coefficients[3]-zg$coefficients[4]),scale=
	exp(zg$coefficients[1]-zg$coefficients[2]-zg$coefficients[3]+
	zg$coefficients[4]))/(1-pgamma(t,exp(zg$coefficients[3]-
	zg$coefficients[4]),scale=exp(zg$coefficients[1]-zg$coefficients[2]-
	zg$coefficients[3]+zg$coefficients[4]))),lty=4)
legend(20,0.05,bty="n",legend=c("Log Laplace","  Radiotherapy",
	"  + chemotherapy","Gamma","  Radiotherapy","  + chemotherapy"),
	lty=c(0,1,2,0,3,4))
dev.off()
}

if(interactive()){
zz <- wr(~treat)
mu <- function(p) p[1]+pp*zz$design[,2]
shape <- function(p) p[1]+p[2]*zz$design[,2]
like1 <- NULL
for(pp in seq(-1.2,-0.2,by=0.05)){
	z <- gnlr(ly,"Laplace",pmu=1,psh=c(2,0),mu=mu,shape=shape,
		delta=delta/surv,exact=T)
	cat(pp,z$maxlike,"\n")
	like1 <- c(like1,z$maxlike)}
like1 <- c(like1[1:12],140.788,like1[13:21])
postscript(file="cosmlike.eps",height=5)
par(mfrow=c(1,2),mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(c(seq(-1.2,-0.65,by=0.05),-0.62778,seq(-0.6,-0.2,by=0.05)),
	exp(-like1+min(like1)),type="l",ylim=c(0,1),xlab=expression(mu),
	ylab="Normed profile likelihood")

mu <- function(p) p[1]+p[2]*zz$design[,2]
shape <- function(p) p[1]+pp*zz$design[,2]
like2 <- NULL
for(pp in seq(-1.5,0,by=0.075)){
	z <- gnlr(ly,"Laplace",pmu=c(1,0),psh=2,mu=mu,shape=shape,
		delta=delta/surv,exact=T)
	cat(pp,z$maxlike,"\n")
	like2 <- c(like2,z$maxlike)}
plot(exp(seq(-1.5,0,by=0.075)),exp(-like2+min(like2)),type="l",
	ylim=c(0,1),xlab=expression(phi),ylab="")
dev.off()
}
