library(gnlm)
library(event)

data <- read.table("leukemia.dat",skip=6,head=T)
reps <- rmna(restovec(c(data[[1]],data[[3]]),censor=c(data[[2]],data[[4]]),
	name="y"),ccov=tcctomat(c(rep(0,21),rep(1,21)),name="treatment"))
reps <- transform(reps,ly=log(y))

gnlr(y,dist="exponential",mu=~exp(a),pmu=1,env=reps)
gnlr(y,dist="exponential",mu=~exp(a+b*treatment),pmu=c(2.5,0),env=reps)

gnlr(y,dist="Weibull",mu=~exp(a),pmu=2.5,psh=1,env=reps)
print(zw <- gnlr(y,dist="Weibull",mu=~exp(a+b*treatment),pmu=c(2.5,-0.7),
	psh=1,env=reps))
exp(zw$coef[3])

gnlr(y,dist="gamma",mu=~exp(a),pmu=2.5,psh=1,env=reps)
print(zg <- gnlr(y,dist="gamma",mu=~exp(a+b*treatment),pmu=c(2.5,-0.7),
	psh=1,env=reps))
exp(zg$coef[3])

gnlr(y,dist="inverse Gauss",mu=~exp(a),pmu=2.5,psh=1,env=reps)
print(zig <- gnlr(y,dist="inverse Gauss",mu=~exp(a+b*treatment),
	pmu=c(11,-9),psh=-2,env=reps))

gnlr(ly,dist="normal",mu=~exp(a),pmu=1,psh=0,env=reps)
gnlr(ly,dist="normal",mu=~exp(a+b*treatment),pmu=c(1,-0.7),psh=0,env=reps)

gnlr(ly,dist="logistic",mu=~exp(a),pmu=1,psh=0,env=reps)
gnlr(ly,dist="logistic",mu=~exp(a+b*treatment),pmu=c(1,-0.7),psh=0,env=reps)

gnlr(ly,dist="Cauchy",mu=~exp(a),pmu=1,psh=0,env=reps)
gnlr(ly,dist="Cauchy",mu=~exp(a+b*treatment),pmu=c(1,-0.7),psh=0,env=reps)

gnlr(ly,dist="Laplace",mu=~exp(a),pmu=1,psh=0,env=reps)
gnlr(ly,dist="Laplace",mu=~exp(a+b*treatment),pmu=c(1,-0.7),psh=0,env=reps)

gnlr3(y,dist="gamma",mu=~exp(a),pmu=-10,psh=3.1,pfam=-1.6,env=reps,iter=200)
print(zgg <- gnlr3(y,dist="gamma",mu=~exp(a+b*treatment),pmu=c(2.5,-0.7),
	psh=1,pfam=0,env=reps))
exp(zgg$coef[3:4])

if(interactive()){
postscript(file="leukemia.eps",height=5)
par(mfrow=c(1,2),mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(z <- km(response(reps,name="y")[,1],censor=response(reps,name="y")[,2],
	group=covariates(reps)),main="",xlab="Weeks",
	ylab="Probability of nonremission",lty=c(1,1))
lines(1:35,1-pgamma(1:35,exp(zg$coef[3]),scale=exp(zg$coef[1]-zg$coef[3])),
	lty=1)
lines(1:35,1-pgamma(1:35,exp(zg$coef[3]),scale=exp(zg$coef[1]+zg$coef[2]-
	zg$coef[3])),lty=2)
lines(1:35,1-pweibull(1:35,exp(zw$coef[3]),scale=exp(zw$coef[1])),
	lty=3)
lines(1:35,1-pweibull(1:35,exp(zw$coef[3]),scale=exp(zw$coef[1]+zw$coef[2])),
	lty=4)
plot(1:35,dgamma(1:35,exp(zg$coef[3]),scale=exp(zg$coef[1]-zg$coef[3]))/
	(1-pgamma(1:35,exp(zg$coef[3]),scale=exp(zg$coef[1]-zg$coef[3]))),
	type="l",lty=1,xlab="Weeks",ylab="Intensity of remission",
	ylim=c(0,0.4))
lines(1:35,dgamma(1:35,exp(zg$coef[3]),scale=exp(zg$coef[1]+zg$coef[2]-
	zg$coef[3]))/(1-pgamma(1:35,exp(zg$coef[3]),scale=exp(zg$coef[1]+
	zg$coef[2]-zg$coef[3]))),lty=2)
lines(1:35,dweibull(1:35,exp(zw$coef[3]),scale=exp(zw$coef[1]))/
	(1-pweibull(1:35,exp(zw$coef[3]),scale=exp(zw$coef[1]))),
	lty=3)
lines(1:35,dweibull(1:35,exp(zw$coef[3]),scale=exp(zw$coef[1]+zw$coef[2]))/
	(1-pweibull(1:35,exp(zg$coef[3]),scale=exp(zw$coef[1]+zw$coef[2]))),
	lty=4)
legend(0,0.42,legend=c("6-mercaptopurine","   Gamma","   Weibull","Placebo",
	"   Gamma","   Weibull"),lty=c(0,1,3,0,2,4),bty="n")
dev.off()
}
