library(gnlm)
library(event)

data <- read.table("recidivism.dat",skip=1,header=T)
data <- data[data[,1]>0,]
attach(data)
Year <- Year-1

if(interactive()){
postscript(file="recidivism.eps",height=5)
par(mfrow=c(1,2),mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(kmr <- km(Months,Censor,group=Year,freq=Frequency),xlab="Months",main="")
#plot(1:68,-diff(kmr[kmr[,2]==0&kmr[,1]<70,4]),type="l",xlab="Months",
#ylab="Risk",ylim=c(0,0.02))
plot(1:69,Frequency[Year==0&Months<70]/(4418-
cumsum(Frequency[Year==0&Months<70])),type="l",xlab="Months",
ylab="Risk",ylim=c(0,0.02),xlim=c(0,81))
#lines(1:44,-diff(kmr[kmr[,2]==1&kmr[,1]<46,4]),lty=2)
lines(1:45,Frequency[Year==1&Months<46]/(5721-
cumsum(Frequency[Year==1&Months<46])),lty=2)
legend(40,0.02,legend=c("1978","1980"),lty=1:2,bty="n")
dev.off()
}

gnlr(cbind(Months,Censor),dist="exponential",pmu=39,wt=Frequency)
print(ze <- fmr(cbind(Months,Censor),dist="exponential",pmu=30,pmix=0,
	wt=Frequency))
fmr(cbind(Months,Censor),dist="exponential",mu=~Year,pmu=c(30,0),pmix=0,
	wt=Frequency)

gnlr(cbind(Months,Censor),dist="gamma",pmu=46,psh=-0.25,wt=Frequency)
print(zg <- fmr(cbind(Months,Censor),dist="gamma",pmu=44,pmix=0,psh=0.25,
	wt=Frequency))
fmr(cbind(Months,Censor),dist="gamma",mu=~Year,pmu=c(44,0),pmix=0,psh=0.25,
	wt=Frequency)

gnlr(cbind(Months,Censor),dist="Weibull",pmu=46,psh=-0.25,wt=Frequency)
print(zw <- fmr(cbind(Months,Censor),dist="Weibull",pmu=44,pmix=0,psh=0.25,
	wt=Frequency))
fmr(cbind(Months,Censor),dist="Weibull",mu=~Year,pmu=c(44,0),pmix=0,psh=0.25,
	wt=Frequency)

gnlr(cbind(Months,Censor),dist="inverse Gauss",pmu=46,psh=-0.25,wt=Frequency)
print(zig <- fmr(cbind(Months,Censor),dist="inverse Gauss",pmu=400,pmix=0,
	psh=0.25,wt=Frequency))
fmr(cbind(Months,Censor),dist="inverse Gauss",mu=~Year,pmu=c(100,-10),
	pmix=0.28,psh=-2.7,wt=Frequency)

gnlr(cbind(log(Months),Censor),dist="normal",pmu=4,psh=0.25,wt=Frequency,
	delta=1/Months)
gnlr(cbind(log(Months),Censor),dist="normal",mu=~Year,pmu=c(4,0),psh=0.25,
	wt=Frequency,delta=1/Months)
print(zln <- fmr(cbind(log(Months),Censor),dist="normal",pmu=4,pmix=0,psh=1.25,
	wt=Frequency,delta=1/Months))
print(zln2 <- fmr(cbind(log(Months),Censor),dist="normal",mu=~Year,pmu=c(4,0),
	pmix=-0.16,psh=0.25,wt=Frequency,delta=1/Months))
exp(zln2$coef[3])/(1+exp(zln2$coef[3]))
print(zln3 <- fmr(cbind(log(Months),Censor),dist="normal",mu=~Year,pmu=c(4,0),
	mix=~Year,pmix=c(-0.2,0),psh=1.25,wt=Frequency,delta=1/Months))

gnlr(cbind(log(Months),Censor),dist="logistic",pmu=4,psh=0.25,wt=Frequency,
	delta=1/Months)
print(zll <- fmr(cbind(log(Months),Censor),dist="logistic",pmu=4,pmix=0,
	psh=1.25,wt=Frequency,delta=1/Months))
fmr(cbind(log(Months),Censor),dist="logistic",mu=~Year,pmu=c(4,0),pmix=0,
	psh=1.25,wt=Frequency,delta=1/Months)

gnlr(cbind(log(Months),Censor),dist="Laplace",pmu=4,psh=0.25,wt=Frequency,
	delta=1/Months)
print(zlla <- fmr(cbind(log(Months),Censor),dist="Laplace",pmu=3,pmix=-0.2,
	psh=-0.1,wt=Frequency,delta=1/Months))
fmr(cbind(log(Months),Censor),dist="Laplace",mu=~Year,pmu=c(4,0),pmix=-0.2,
	psh=-0.1,wt=Frequency,delta=1/Months)

gnlr(cbind(log(Months),Censor),dist="Cauchy",pmu=4,psh=0.25,wt=Frequency,
	delta=1/Months)
print(zlc <- fmr(cbind(log(Months),Censor),dist="Cauchy",pmu=3,pmix=-0.2,
	psh=-0.1,wt=Frequency,delta=1/Months))
fmr(cbind(log(Months),Censor),dist="Cauchy",mu=~Year,pmu=c(4,0),pmix=-0.2,
	psh=-0.1,wt=Frequency,delta=1/Months)

if(interactive()){
postscript(file="recidmodel.eps",height=5)
par(mfrow=c(1,2),mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(c(1,81),rep(1/ze$coef[1],2),ylim=c(0,0.08),xlab="Months",
	ylab="Risk",type="l")
lines(1:81,exp(hlnorm(1:81,zln$coef[1],exp(zln$coef[3]/2))),lty=2)
lines(1:81,exp(hlogis(log(1:81),zll$coef[1],exp(zll$coef[3])*sqrt(3)/pi))/
	(1:81),lty=3)
lines(1:81,exp(hgamma(1:81,exp(zg$coef[3]),scale=zg$coef[1]/exp(zg$coef[3]))),
	lty=4)
lines(1:81,exp(hweibull(1:81,exp(zw$coef[3]),zw$coef[1])),lty=5)
lines(1:81,exp(hinvgauss(1:81,zig$coef[1],exp(zig$coef[3]))),lty=6)
legend(0,0.085,legend=c("Exponential","Log normal","Log logistic",
	"Gamma","Weibull","Inverse Gauss"),lty=1:6,bty="n")
plot(1:81,exp(hlnorm(1:81,zln2$coef[1],exp(zln2$coef[4]/2))),ylim=c(0,0.08),
	xlab="Months",ylab="",type="l")
lines(1:81,exp(hlnorm(1:81,zln2$coef[1]+zln2$coef[2],exp(zln2$coef[4]/2))),
	lty=2)
legend(40,0.08,legend=c("1978","1980"),lty=1:2,bty="n")
dev.off()
}
