library(event)
library(gnlm)

y <- scan("vehicles.dat",skip=1)

if(interactive()){
postscript(file="vehicles.eps",height=5,width=5)
par(mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
cprocess(y,xlab="Seconds",ylab="Number of vehicles")
dev.off()
}

length(y)/sum(y)
length(y)/sum(y)*60

sy <- cumsum(y)
int <- seq(0,2040,by=60)
times <- seq(30,2040,by=60)
if(interactive()){
postscript(file="vehiclehist.eps",height=5,width=5)
par(mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
freq <- hist(sy,breaks=int,xlab="Minutes",ylab="Vehicles",main="")$counts
box()
dev.off()
}else{
freq <- rep(0,34)
for(i in 1:34)freq[i] <- sum(sy>=int[i]&sy<int[i+1])
}

if(interactive()){
postscript(file="vehicleauto.eps",height=5,width=5)
par(mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
autointensity(y,window=8,maxlag=max(y),main="",xlab="Lag (s)")
dev.off()
}

print(zp <- summary(glm(freq~1,family=poisson)))
zp$aic/2
print(zpt <- summary(glm(freq~times,family=poisson)))
zpt$aic/2
print(zpt2 <- summary(glm(freq~times+I(times^2),family=poisson)))
zpt2$aic/2

tmp <- table(freq)
fr <- rep(0,13)
fr[as.numeric(names(tmp))+1] <- tmp

mean(fr)
var(fr)

if(interactive()){
postscript(file="vehiclefreq.eps",height=5,width=5)
par(mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
print(zpc <- fit.dist(0:12,fr,dist="Poisson",plot=T,main="",
	xlab="Number of vehicles in one minute"))
print(znbc <- fit.dist(0:12,fr,dist="negative binomial",plot=T,add=T,lty=2))
legend(6,0.22,legend=c("Poisson","Negative binomial"),lty=1:2,bty="n")
dev.off()
}else{
print(zpc <- fit.dist(0:12,fr,dist="Poisson"))
print(znbc <- fit.dist(0:12,fr,dist="negative binomial"))
}
-sum(fr[fr>0]*log((fr/sum(fr))[fr>0]))+length(fr)
-sum(fr[fr>0]*log(zpc[fr>0,4]))+1
-sum(fr[fr>0]*log(znbc[fr>0,4]))+2

gnlr(freq,mu=~1,pmu=3.8,dist="Poisson")
gnlr(freq,mu=~1,pmu=3.8,psh=1,dist="negative binomial")
gnlr(freq,mu=~1,pmu=3.8,psh=0.05,dist="double Poisson")
gnlr(freq,mu=~1,pmu=3.8,psh=0.5,dist="mult Poisson")
gnlr(freq,mu=~1,pmu=3.8,psh=0.05,dist="gamma count")

mean(y)
sd(y)

if(interactive()){
postscript(file="vehiclekm.eps",height=5,width=5)
par(mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(km(y),xlab="Seconds",ylab="'Survival' probability",main="")
dev.off()

postscript(file="vehicledist.eps")
par(mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot.dist(km(y))
dev.off()
}

gnlr(y,dist="exponential",mu=~1,pmu=16)
print(zg <- gnlr(y,dist="gamma",mu=~1,pmu=16,psh=1))
exp(zg$coef[2])
print(zln <- gnlr(log(y),dist="normal",mu=~1,pmu=log(16),psh=1,delta=1/y))
print(zll <- gnlr(log(y),dist="logistic",mu=~1,pmu=log(16),psh=1,delta=1/y))
print(zw <- gnlr(y,dist="Weibull",mu=~1,pmu=16,psh=1))
exp(zw$coef[2])
print(zn <- gnlr(y,dist="normal",mu=~1,pmu=16,psh=6))

if(interactive()){
postscript(file="vehicleint.eps",height=5,width=5)
par(mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(1:125,exp(hgamma(1:125,exp(zg$coef[2]),zg$coef[1]/exp(zg$coef[2]))),
	type="l",lty=2,xlab="Seconds",ylab="Intensity",ylim=c(0,0.15))
lines(c(1,125),rep(1/zg$coef[1],2))
lines(1:125,exp(hlnorm(1:125,zln$coef[1],exp(zln$coef[2]/2))),lty=3)
lines(1:125,exp(hlogis(log(1:125),zll$coef[1],exp(zll$coef[2])*sqrt(3)/pi))/
	(1:125),lty=4)
lines(1:125,exp(hweibull(1:125,exp(zw$coef[2]),zw$coef[1])),lty=5)
legend(60,0.14,legend=c("Exponential","Gamma","Log normal","Log logistic",
	"Weibull"),lty=1:5,bty="n")
dev.off()
}


t <- c(0,cumsum(y)[1:127])
n <- 1:128

if(interactive()){
postscript(file="vehicletime.eps",height=5)
par(mfrow=c(1,2),mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(n,y,type="l",pch=20,xlab="Event number",ylab="Interarrival time")
plot(t,y,type="l",pch=20,xlab="Arrival time",ylab="")
dev.off()
}

gnlr(y,dist="exponential",mu=~exp(a+b*t),pmu=c(3,0))
print(zgt <- gnlr(y,dist="gamma",mu=~exp(a+b*t),pmu=c(2.8,-0.001),psh=-0.3))
print(zlnt <- gnlr(log(y),dist="normal",mu=~a+b*t,pmu=c(1.86,-0.001),
	psh=0.6,delta=1/y))
print(zllt <- gnlr(log(y),dist="logistic",mu=~a+b*t,pmu=c(1.86,-0.001),
	psh=0.4,delta=1/y))
print(zwt <- gnlr(y,dist="Weibull",mu=~exp(a+b*t),pmu=c(2.8,-0.001),psh=-0.3))
print(znt <- gnlr(y,dist="normal",mu=~a+b*t,pmu=c(16,0),psh=6))

gnlr(y,dist="exponential",mu=~exp(a+b*n),pmu=c(3,0))
print(zgn <- gnlr(y,dist="gamma",mu=~exp(a+b*n),pmu=c(2.8,-0.001),psh=-0.3))
print(zlnn <- gnlr(log(y),dist="normal",mu=~a+b*n,pmu=c(1.86,-0.001),
	psh=0.6,delta=1/y))
print(zlln <- gnlr(log(y),dist="logistic",mu=~a+b*n,pmu=c(1.86,-0.001),
	psh=0.4,delta=1/y))
print(zwn <- gnlr(y,dist="Weibull",mu=~exp(a+b*n),pmu=c(2.8,-0.001),psh=-0.3))
print(znn <- gnlr(y,dist="normal",mu=~a+b*n,pmu=c(16,0),psh=6))

print(zlndt <- gnlr(log(y),dist="normal",mu=~1,pmu=1.86,
shape=~a+b*t,psh=c(0.6,-0.001),delta=1/y))
print(zlndn <- gnlr(log(y),dist="normal",mu=~1,pmu=1.86,
shape=~a+b*n,psh=c(0.6,-0.001),delta=1/y))
