library(event)

rain <- scan("rain.dat",skip=3)
year <- gl(11,30,330)
day <- rep(1:30,11)
wt <- day>1

if(interactive()){
postscript("rain.eps",height=5,width=5)
par(mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
cprocess(events=matrix(rain,ncol=30,byrow=T),lty=rep(1,11),ylim=c(0,15),
	xlab="Day",ylab="Total rainy days")
dev.off()
}

sum(rain)
sum(rain==0)
sum(rain)/length(rain)
print(fr1 <- table(rain[day<30],rain[wt]))
print(t1 <- fr1/rep(table(rain[day<30]),2))
1/(1-t1[1,1])
1/(1-t1[2,2])
table(rain[day<29],rain[day>2])
table(rain[day<29],rain[day>2])/rep(table(rain[day<29]),2)
t1%*%t1

# models using the binary series
summary(z0 <- glm(rain~1,family=binomial,weights=wt))
z0$aic/2
# unconditional probability of rain
1/(1+exp(-z0$coef))
sum(rain[wt])/length(rain[wt])
summary(z1 <- glm(rain[2:330]~rain[1:329],family=binomial,weights=wt[2:330]))
z1$aic/2
# probability of rain, given rain the previous day
1/(1+exp(-sum(z1$coef)))
# probability of rain, given dry the previous day
1/(1+exp(-z1$coef[1]))
summary(z2 <- glm(rain[2:330]~rain[1:329]+year[2:330],family=binomial,
	weights=wt[2:330]))
z2$aic/2
summary(z3 <- glm(rain[2:330]~rain[1:329]*year[2:330],family=binomial,
	weights=wt[2:330]))
z3$aic/2
summary(z4 <- glm(rain[2:330]~rain[1:329]+as.numeric(year[2:330]),
	family=binomial,weights=wt[2:330]))
z4$aic/2
summary(z5 <- glm(rain[2:330]~rain[1:329]+day[2:330],family=binomial,
	weights=wt[2:330]))
z5$aic/2

# logistic models using the table
print(za0 <- glm(fr1~1,family=binomial))
za0$aic/2
print(za1 <- glm(fr1~gl(2,1),family=binomial))
za1$aic/2

fr2 <- as.vector(fr1)
tt1 <- gl(2,1,4)
tt2 <- gl(2,2,4)
print(zb0 <- glm(fr2~tt1+tt2,family=poisson))
zb0$aic/2
print(zb1 <- glm(fr2~tt1*tt2,family=poisson))
zb1$aic/2

wt2 <- day>2
summary(z20 <- glm(rain~1,family=binomial,weights=wt2))
z20$aic/2
summary(z21 <- glm(rain[2:330]~rain[1:329],family=binomial,weights=wt2[2:330]))
z21$aic/2
summary(z22 <- glm(rain[3:330]~rain[1:328],family=binomial,weights=wt2[3:330]))
z22$aic/2
summary(z23 <- glm(rain[3:330]~rain[2:329]+rain[1:328],family=binomial,
	weights=wt2[3:330]))
z23$aic/2
summary(z24 <- glm(rain[3:330]~rain[2:329]+rain[1:328]+rain[2:329]*rain[1:328],
	family=binomial,weights=wt2[3:330]))
z24$aic/2

if(interactive()){
obsmarg <- apply(matrix(rain,nrow=11,byrow=T),2,sum)/11
thmarg <- c(obsmarg[1],rep(0,29))
for(i in 2:30)thmarg[i] <- (c(1-thmarg[i-1],thmarg[i-1])%*%t1)[2]
postscript("rain2.eps",height=5,width=5)
par(mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(1:30,obsmarg,pch=20,ylim=c(0,1),xlab="Day",ylab=expression(pi[1]))
lines(1:30,thmarg)
legend(10,1,legend=c("Observed","Markov chain"),pch=c(20,-1),lty=c(-1,1),
	bty="n")
dev.off()
}
