library(rmutil)

data <- read.table("methadone.dat",skip=3,head=T)
attach(data)

tran <- array(t(as.matrix(data[,3:11])),c(3,3,30))
dif <- rep(c(2,2,3),10)
time <- c(1,3,5.5,8,10,12.5,15,17,19.5,22,24,26.5,
	1,3,5.5,8,10,12.5,15,17,19.5,1,3,5.5,8,10,12.5,15,17,19.5)

# saturated model
print(prob <- tran/array(apply(apply(tran,c(1,3),sum),2,rep,3),c(3,3,30)))
-sum(tran*log(ifelse(prob==0,1,prob)))+180

like <- function(p){
	p <- exp(p)
	mat <- matrix(c(-p[1]-p[2],p[1],p[2],
			p[3],-p[3]-p[4],p[4],
			p[5],p[6],-p[5]-p[6]),ncol=3,byrow=T)
	mat2 <- mexp(mat,2)
	mat3 <- mexp(mat,3)
	like <- 0
	for(i in slen:elen)
		like <- like-sum(t(tran[,,i])*log(if(dif[i]==2)mat2 else mat3))
	like}

# same transition matrix for all treatments
slen <- 1
elen <- 30
print(zf <- nlm(like,p=rep(-4,6)))
p <- exp(zf$est)
print(pintf <- matrix(c(-p[1]-p[2],p[1],p[2],p[3],-p[3]-p[4],p[4],
	p[5],p[6],-p[5]-p[6]),ncol=3,byrow=T))
mexp(pintf)
zf$min+6


# different transition matrices for all treatments
slen <- 1
elen <- 12
print(z1 <- nlm(like,p=rep(-4,6)))
p <- exp(z1$est)
print(pint1 <- matrix(c(-p[1]-p[2],p[1],p[2],p[3],-p[3]-p[4],p[4],
	p[5],p[6],-p[5]-p[6]),ncol=3,byrow=T))
mexp(pint1)

slen <- 13
elen <- 21
print(z2 <- nlm(like,p=rep(-4,6)))
p <- exp(z2$est)
print(pint2 <- matrix(c(-p[1]-p[2],p[1],p[2],p[3],-p[3]-p[4],p[4],
	p[5],p[6],-p[5]-p[6]),ncol=3,byrow=T))
mexp(pint2)

slen <- 22
 elen <- 30
print(z3 <- nlm(like,p=rep(-4,6)))
p <- exp(z3$est)
print(pint3 <- matrix(c(-p[1]-p[2],p[1],p[2],p[3],-p[3]-p[4],p[4],
	p[5],p[6],-p[5]-p[6]),ncol=3,byrow=T))
mexp(pint3)
z1$min+z2$min+z3$min+18

# same transition matrix for both Methadone treatments
slen <- 13
elen <- 30
print(z23 <- nlm(like,p=rep(-3,6)))
p <- exp(z23$est)
print(pint23 <- matrix(c(-p[1]-p[2],p[1],p[2],p[3],-p[3]-p[4],p[4],
	p[5],p[6],-p[5]-p[6]),ncol=3,byrow=T))
mexp(pint23)
z1$min+z23$min+12

liket <- function(p){
	mat <- function(i){
		p <- exp(c(p[1:4],p[5]+time[i]*p[7],p[6]+time[i]*p[7]))
		matrix(c(-p[1]-p[2],p[1],p[2],p[3],-p[3]-p[4],p[4],
			p[5],p[6],-p[5]-p[6]),ncol=3,byrow=T)}
	like <- 0
	for(i in slen:elen){
		matt <- mat(i)
		like <- like-sum(t(tran[,,i])*log(if(dif[i]==2)
		mexp(matt,2) else mexp(matt,3)))}
	as.numeric(like)}

#  time dependence
# same transition matrix for all treatments
slen <- 1
elen <- 30
print(ztf <- nlm(liket,p=c(rep(-1,6),0)))
p <- exp(ztf$est)
print(pintft <- matrix(c(-p[1]-p[2],p[1],p[2],p[3],-p[3]-p[4],p[4],
	p[5],p[6],-p[5]-p[6]),ncol=3,byrow=T))
mexp(pintft)
ztf$min+7

# different transition matrices for all treatments
slen <- 1
elen <- 12
print(zt1 <- nlm(liket,p=c(rep(-2,6),0)))
p <- exp(zt1$est[1:6])
print(pint1t <- matrix(c(-p[1]-p[2],p[1],p[2],p[3],-p[3]-p[4],p[4],
	p[5],p[6],-p[5]-p[6]),ncol=3,byrow=T))
mexp(pint1t)

slen <- 13
elen <- 21
print(zt2 <- nlm(liket,p=c(rep(-2,6),0)))
p <- exp(zt2$est[1:6])
print(pint2t <- matrix(c(-p[1]-p[2],p[1],p[2],p[3],-p[3]-p[4],p[4],
	p[5],p[6],-p[5]-p[6]),ncol=3,byrow=T))
mexp(pint2t)

slen <- 22
elen <- 30
print(zt3 <- nlm(liket,p=c(rep(-1,6),0)))
p <- exp(zt3$est[1:6])
print(pint3t <- matrix(c(-p[1]-p[2],p[1],p[2],p[3],-p[3]-p[4],p[4],
	p[5],p[6],-p[5]-p[6]),ncol=3,byrow=T))
mexp(pint3t)
zt1$min+zt2$min+zt3$min+21

# same transition matrix for both Methadone treatments
slen <- 13
elen <- 30
print(zt23 <- nlm(liket,p=c(rep(-1,6),0)))
p <- exp(zt23$est)
print(pint23t <- matrix(c(-p[1]-p[2],p[1],p[2],p[3],-p[3]-p[4],p[4],
	p[5],p[6],-p[5]-p[6]),ncol=3,byrow=T))
mexp(pint23t)
zt1$min+zt23$min+14
