library(gnlm)
library(repeated)

data <- read.table("animal.dat",skip=5)
train <- codes(gl(2,8,16))==1
stimulus <- codes(gl(2,4,16))==1
y <- list()
for(i in 1:ncol(data)){
	y <- c(y,list(cbind(c(data[1:10,i],data[11:20,i][data[11:20,i]>0]),
		1:(10+length(data[11:20,i][data[11:20,i]>0])))))}
yb <- restovec(y,total=20)
y <- restovec(y)
repsb <- rmna(yb,ccov=tcctomat(~train+stimulus))

if(interactive()){
postscript("animal0.eps")
par(mfrow=c(2,2),font.main=1,mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(y,nind=1,pch=1,yaxt="n",xlim=c(0,20),ylim=c(0,25),
	xlab="",ylab="Successes",main="Not trained - Bell")
axis(2,c(0,5,10,15,20))
for(i in 2:4)plot(y,nind=i,pch=i+20,add=T)
plot(y,nind=5,pch=1,yaxt="n",xlim=c(0,20),ylim=c(0,25),
	xlab="",ylab="",main="Not trained - Light")
axis(2,c(0,5,10,15,20))
for(i in 2:4)plot(y,nind=i+4,pch=i+20,add=T)
plot(y,nind=9,pch=1,yaxt="n",xlim=c(0,20),ylim=c(0,25),
	xlab="Trial",ylab="Successes",main="Pre-trained - Bell")
axis(2,c(0,5,10,15,20))
for(i in 2:4)plot(y,nind=i+8,pch=i+20,add=T)
plot(y,nind=13,pch=1,yaxt="n",xlim=c(0,20),ylim=c(0,25),
	xlab="Trial",ylab="",main="Pre-trained - Light")
axis(2,c(0,5,10,15,20))
for(i in 2:4)plot(y,nind=i+12,pch=i+20,add=T)
dev.off()
}

mu1a <- function(p) p[1]+p[2]*times+p[3]*stimulus
mu1ai <- function(p) p[1]+p[2]*times+p[3]*stimulus+p[4]*stimulus*times
mu1ali <- function(p)
	1/(1+exp(-(p[1]+p[2]*times+p[3]*stimulus+p[4]*stimulus*times)))
mu1lli <- function(p) exp(-exp(p[1]+p[2]*times+p[3]*stimulus+
	p[4]*stimulus*times))
mu1clli <- function(p) 1-exp(-exp(p[1]+p[2]*times+p[3]*stimulus+
	p[4]*stimulus*times))

gnlr(repsb,dist="binomial",mu=mu1ali,pmu=c(-3.6,0.46,1.83,0))
gnlr(repsb,dist="beta binomial",mu=mu1ali,pmu=c(-3.6,0.46,1.83,0),psh=1)
gnlr(repsb,dist="mult binomial",mu=mu1ali,pmu=c(-3.6,0.46,1.83,0),psh=1)
gnlr(repsb,dist="double binomial",mu=mu1ali,pmu=c(-0.8,0.1,0.4,0),psh=-2)

gnlr(repsb,dist="binomial",mu=mu1lli,pmu=c(1.9,-0.3,-1.1,0))
gnlr(repsb,dist="beta binomial",mu=mu1lli,pmu=c(1.9,-0.3,-1.1,0),psh=1)
gnlr(repsb,dist="mult binomial",mu=mu1lli,pmu=c(1.9,-0.3,-1.1,0),psh=1)
gnlr(repsb,dist="double binomial",mu=mu1lli,pmu=c(1.9,-0.3,-1.1,0),psh=1)

gnlr(repsb,dist="binomial",mu=mu1clli,pmu=c(-1.9,-0.3,-1.1,0))
gnlr(repsb,dist="beta binomial",mu=mu1clli,pmu=c(-1.9,-0.3,-1.1,0),psh=1)
gnlr(repsb,dist="mult binomial",mu=mu1clli,pmu=c(-1.9,-0.3,-1.1,0),psh=1)
gnlr(repsb,dist="double binomial",mu=mu1clli,pmu=c(-1.9,-0.3,-1.1,0),psh=1)

gar(repsb,dist="binomial",mu=mu1ai,preg=c(-2,0.3,0,0),pdep=0.1,link="logit")
gar(repsb,dist="beta binomial",mu=mu1ai,preg=c(-2,0.3,0,0),
	 psh=1,pdep=0.5,link="logit")
gar(repsb,dist="mult binomial",mu=mu1ai,preg=c(-2,0.3,0,0),
	 psh=1,pdep=0.1,link="logit")
gar(repsb,dist="double binomial",mu=mu1ai,preg=c(-2,0.3,0,0),
	 psh=0.1,pdep=0.1,link="logit")

gar(repsb,dist="binomial",mu=mu1ai,preg=c(-3,0.4,0,0.5),pdep=0.1,
	link="cloglog")
gar(repsb,dist="beta binomial",mu=mu1ai,preg=c(-3,0.3,-0.3,0.5),pdep=0.1,
	psh=1,link="cloglog")
gar(repsb,dist="mult binomial",mu=mu1ai,preg=c(-1,0,0.2,0),pdep=0.1,
	psh=1,link="cloglog")
gar(repsb,dist="double binomial",mu=mu1ai,preg=c(-3,0.3,1,0),pdep=0.1,
	psh=0.17,link="cloglog")

gar(repsb,dist="binomial",mu=mu1ai,preg=c(1.6,-0.3,0,0),pdep=0.1,
	link="loglog")
gar(repsb,dist="beta binomial",mu=mu1ai,preg=c(-2,0.3,0,0),
	psh=1,pdep=0.5,link="loglog")
gar(repsb,dist="mult binomial",mu=mu1ai,preg=c(2,-0.4,-0.1,0),
	psh=1,pdep=0.1,link="loglog")
gar(repsb,dist="double binomial",mu=mu1ai,preg=c(2,-0.4,-0.1,0),
	psh=0.1,pdep=0.1,link="loglog")

print(zdb2 <- gar(repsb,dist="double binomial",mu=mu1a,preg=c(-4,0.6,2),
	 psh=0.3,pdep=0.03,link="logit"))

if(interactive()){
mu1ap <- function(p,times,stimulus) exp(p[1]+p[2]*times+p[3]*stimulus)/
      (1+exp(p[1]+p[2]*times+p[3]*stimulus))*20
postscript("animal1b.eps")
par(mfrow=c(2,2),font.main=1,mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(iprofile(zdb2),nind=1:2,lty=c(3,2),pch=c(21,22),xlim=c(0,20),ylim=c(0,25),
	xlab="",ylab="Successes",main="Not trained - Bell",yaxt="n")
axis(2,c(0,5,10,15,20))
lines(1:20,mu1ap(zdb2$coef,1:20,1))
plot(iprofile(zdb2),nin=5:6,lty=c(3,2),pch=c(21,22),xlim=c(0,20),ylim=c(0,25),
	xlab="",ylab="",main="Not trained - Light",yaxt="n")
axis(2,c(0,5,10,15,20))
lines(1:20,mu1ap(zdb2$coef,1:20,0))
plot(iprofile(zdb2),nind=9:10,lty=c(3,2),pch=c(21,22),xlim=c(0,20),
	ylim=c(0,25),xlab="Trial",ylab="Successes",main="Pre-trained - Bell",
	yaxt="n")
axis(2,c(0,5,10,15,20))
lines(1:20,mu1ap(zdb2$coef,1:20,1))
plot(iprofile(zdb2),nind=13:14,lty=c(3,2),pch=c(21,22),xlim=c(0,20),
	ylim=c(0,25),xlab="Trial",ylab="",main="Pre-trained - Light",yaxt="n")
axis(2,c(0,5,10,15,20))
lines(1:20,mu1ap(zdb2$coef,1:20,0))
dev.off()
}
