library(gnlm)
library(event)

surv <- read.surv("cancer.dat",skip=5,nline=1,cum=F,all=F)
# lagged times, observation numbers, and weights
y1 <- sh <- nr <- list()
for(i in surv[[1]]){
	nr <- c(nr,list(1:length(i)))
	y1 <- c(y1,list(if(length(i)==1) 1
		else c(1,i[1:(length(i)-1)])))
	sh <- c(sh,list(log(y1[[length(y1)]])))}
treat <- as.factor(c(rep(1,47),rep(2,31),rep(3,38)))
tvc <- tvctomat(y1,name="y1")
tvc <- tvctomat(sh,name="sh",old=tvc)
tvc <- tvctomat(nr,name="nr",old=tvc)
reps <- rmna(restovec(surv[[1]],censor=surv[[2]],name="surv"),
	ccov=tcctomat(treat,dataframe=F),tvcov=tvc)
reps <- transform(reps,lsurv=log(surv))

if(interactive()){
postscript("cancer.eps",height=5)
nr <- sequence(nobs(reps))
tr <- treat[covind(reps)]
par(mfrow=c(1,2),mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(km(response(reps)[nr==1,1],group=tr[nr==1],
	censor=response(reps)[nr==1,2]),main="",xlab="Months",
	ylab="Nonrecurrence probability",xaxt="n")
axis(1,c(0,20,40,60))
plot(km(response(reps)[nr>1,1],group=tr[nr>1],
	censor=response(reps)[nr>1,2]),xlim=c(0,60),main="",
	xlab="Months",ylab="",xaxt="n")
axis(1,c(0,20,40,60))
legend(20,1,legend=c("Placebo","Pyridoxine","Thiotepa"),lty=1:3,bty="n")
dev.off()
}

# Weibull
# null model
gnlr(surv,"Weibull",pmu=3,pshape=0,mu=~exp(a),env=reps)
gnlr3(surv,"Burr",pmu=2,pshape=0.6,pfam=-0.3,mu=~exp(a),env=reps)
# or
print(zwi <- kalsurv(surv,pinit=0.8,preg=1,psh=1,
	dep="independence",intensity="Weibull",env=reps))
print(zwm <- kalsurv(surv,pinit=0.93,pdep=0.4,preg=2.8,psh=1.2,
	dep="serial",upd="Markov",intensity="Weibull",env=reps))
print(zwc <- kalsurv(surv,pinit=0.8,pdep=0.5,preg=1,psh=1,
	dep="serial",upd="count",intensity="Weibull",env=reps))
print(zw <- kalsurv(surv,pinit=0.1,preg=1,psh=1,intensity="Weibull",
	dep="frailty",env=reps))
# treatment
gnlr(surv,"Weibull",pmu=c(8,-1,-1),pshape=0,mu=~exp(a+b1*treat2+b2*treat3),
	env=reps)
gnlr3(surv,"Burr",pmu=c(5,0,0),pshape=0.6,pfam=-0.3,
	mu=~exp(a+b1*treat2+b2*treat3),env=reps)
# or
print(zwit <- kalsurv(surv,pinit=0.8,psh=1,dep="independence",
	intensity="Weibull",preg=c(1,0,0),
	mu=~exp(a+b1*treat2+b2*treat3),env=reps))
print(zwmt <- kalsurv(surv,pinit=0.8,pdep=0.01,psh=4.5,dep="serial",
	upd="Markov",intensity="Weibull",preg=c(3,0,0),
	mu=~exp(a+b1*treat2+b2*treat3),env=reps))
print(zwct <- kalsurv(surv,pinit=0.8,pdep=0.5,psh=1, dep="serial",
	upd="count",intensity="Weibull",preg=c(1,0,0),
	mu=~exp(a+b1*treat2+b2*treat3),env=reps))
print(zwt <- kalsurv(surv,pinit=1.5,psh=1,preg=c(1,0,0),intensity="Weibull",
	dep="frailty",mu=~exp(a+b1*treat2+b2*treat3),env=reps))
# treatment + birth
gnlr(surv,"Weibull",pmu=c(8,-1,0,0),pshape=0,
	mu=~exp(a+b1*treat2+b2*treat3+c*log(nr)),env=reps)
gnlr3(surv,"Burr",pmu=c(5,0,0,0),pshape=0.6,pfam=-0.3,
	mu=~exp(a+b1*treat2+b2*treat3+c*log(nr)),env=reps)
# or
print(zwitb <- kalsurv(surv,pinit=1.9,psh=1.3,dep="independence",
	intensity="Weibull",ptvc=c(1,0,0,0),
	mu=~exp(a+b1*treat2+b2*treat3+c*log(nr)),env=reps))
print(zwmtb <- kalsurv(surv,pinit=0.8,pdep=0.01,psh=4.5,dep="serial",
	upd="Markov",intensity="Weibull",ptvc=c(3,0.5,0.7,0),
	mu=~exp(a+b1*treat2+b2*treat3+c*log(nr)),env=reps))
print(zwctb <- kalsurv(surv,pinit=0.8,pdep=0.5,psh=1, dep="serial",
	upd="count",intensity="Weibull",ptvc=c(1,0,0,0),
	mu=~exp(a+b1*treat2+b2*treat3+c*log(nr)),env=reps))
print(zwtb <- kalsurv(surv,pinit=0.1,psh=1,ptvc=c(1,0,0,0),
	intensity="Weibull",dep="frailty",
	mu=~exp(a+b1*treat2+b2*treat3+c*log(nr)),env=reps))

# log normal
# null model
gnlr(lsurv,"normal",pmu=2,pshape=0.5,env=reps)
print(zlni <- kalsurv(surv,pinit=0.8,psh=1,
	dep="independence",intensity="log normal",preg=1,env=reps))
print(zlnm <- kalsurv(surv,pinit=0.8,psh=0.5,pdep=0.1,dep="serial",
	upd="Markov",intensity="log normal",preg=4,env=reps))
print(zlnc <- kalsurv(surv,pinit=0.8,psh=0.5,pdep=0.1,dep="serial",
	upd="count",intensity="log normal",preg=4,env=reps))
print(zln <- kalsurv(surv,pinit=0.1,preg=1,psh=1,
	intensity="log normal",dep="frailty",env=reps))
# treatment
gnlr(lsurv,"normal",pmu=c(2,0,0),pshape=0.11,mu=~treat2+treat3,env=reps)
print(zlnit <- kalsurv(surv,pinit=0.8,psh=1,
	dep="independence",intensity="log normal",preg=c(1,0,0),
	mu=~treat2+treat3,env=reps))
print(zlnmt <- kalsurv(surv,pinit=0.8,psh=0.5,pdep=0.1,dep="serial",
	upd="Markov",intensity="log normal",preg=c(4,0.1,0.2),
	mu=~treat2+treat3,env=reps))
print(zlnct <- kalsurv(surv,pinit=0.8,psh=0.5,pdep=0.99,dep="serial",
	upd="count",intensity="log normal",preg=c(4,0.1,0.2),
	mu=~treat2+treat3,env=reps))
print(zlnt <- kalsurv(surv,pinit=1.5,psh=1,preg=c(1,0,0),
	intensity="log normal",dep="frailty",mu=~treat2+treat3,env=reps))
# treatment + birth
gnlr(lsurv,"normal",pmu=c(2,0,0,0),pshape=0.11,mu=~treat2+treat3+log(nr),
	env=reps)
print(zlnitb <- kalsurv(surv,pinit=0.8,psh=1,
	dep="independence",intensity="log normal",ptvc=c(1,0,0,0),
	mu=~treat2+treat3+log(nr),env=reps))
print(zlnmtb <- kalsurv(surv,pinit=0.8,psh=0.5,pdep=0.9,dep="serial",
	upd="Markov",intensity="log normal",ptvc=c(4,0.1,0.2,0),
	mu=~treat2+treat3+log(nr),env=reps))
print(zlnctb <- kalsurv(surv,pinit=0.8,psh=0.5,pdep=0.99,dep="serial",
	upd="count",intensity="log normal",ptvc=c(4,0.1,0.2,0),
	mu=~treat2+treat3+log(nr),env=reps))
print(zlntb <- kalsurv(surv,pinit=0.1,psh=1,ptvc=c(1,0,0,0),
	intensity="log normal",dep="frailty",mu=~treat2+treat3+log(nr),
	env=reps))
# birth
gnlr(lsurv,"normal",pmu=c(2,0),pshape=0.11,mu=~log(nr),env=reps)
print(zlnib <- kalsurv(surv,pinit=0.8,psh=0.5,pdep=0.99,dep="independence",
	intensity="log normal",ptvc=c(4,0),mu=~log(nr),env=reps))
print(zlnmb <- kalsurv(surv,pinit=0.8,psh=0.5,pdep=0.1,dep="serial",
	upd="Markov",intensity="log normal",ptvc=c(4,0),mu=~log(nr),env=reps))
print(zlncb <- kalsurv(surv,pinit=0.8,psh=0.5,pdep=0.99,dep="serial",
	upd="count",intensity="log normal",ptvc=c(4,0),mu=~log(nr),env=reps))
print(zlnb <- kalsurv(surv,pinit=1.5,ptvc=c(1,0),psh=1,
	intensity="log normal",dep="frailty",mu=~log(nr),env=reps))

if(interactive()){
postscript("cancerprof.eps",height=8,width=8)
par(mfrow=c(2,2),mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0),font.main=1)
plot(iprofile(zlncb),nind=45,lty=2,pch=20,xlab="",ylim=c(0,20))
plot(mprofile(zlnmb),nind=45,add=T)
plot(iprofile(zlnmb),nind=45,add=T,lty=3,obs=F)
plot(iprofile(zlncb),nind=63,lty=2,pch=20,xlab="",ylab="",ylim=c(0,20))
plot(mprofile(zlnmb),nind=63,add=T)
plot(iprofile(zlnmb),nind=63,add=T,lty=3,obs=F)
legend(30,20,legend=c("Underlying profile","Markov update","Count update"),
	lty=1:3,bty="n")
plot(iprofile(zlncb),nind=76,lty=2,pch=20,ylim=c(0,20))
plot(mprofile(zlnmb),nind=76,add=T)
plot(iprofile(zlnmb),nind=76,add=T,lty=3,obs=F)
plot(iprofile(zlncb),nind=101,lty=2,pch=20,ylab="",ylim=c(0,20))
plot(mprofile(zlnmb),nind=101,add=T)
plot(iprofile(zlnmb),nind=101,add=T,lty=3,obs=F)
dev.off()
}

# Chapter 8

# independence
gnlr(surv,"gamma",mu=~exp(a),pmu=3,pshape=0.2,env=reps)
gnlr(surv,"gamma",mu=~exp(a+b2*treat2+b3*treat3),pmu=c(2.4,0,0),pshape=0.2,
	env=reps)

# autoregression
gnlr(surv,"gamma",mu=~exp(a*(nr==1)+(b+c*y1)*(nr>1)),pmu=c(3,2,0.2),
	psh=0.2,env=reps)
gnlr(surv,"gamma",mu=~exp(a*(nr==1)+(b+c*sh)*(nr>1)+d2*treat2+d3*treat3),
	psh=-0.05,pmu=c(3,2,0.02,0,0),env=reps)

# autoregression on log
gnlr(surv,"gamma",mu=~exp(a*(nr==1)+(b+c*sh)*(nr>1)),pmu=c(3,2.4,0.02),
	psh=0.2,env=reps)
gnlr(surv,"gamma",mu=~exp(a*(nr==1)+(b+c*sh)*(nr>1)+d2*treat2+d3*treat3),
	psh=0.2,pmu=c(3,2.5,0.04,-0.4,0),env=reps)

# conditional exponential family
shape <- function(p) sh
gnlr(surv,"gamma",mu=~sh,pmu=c(9,0.4),shape=shape,env=reps)
gnlr(surv,"gamma",mu=~a*(nr==1)+(b+c*sh)*(nr>1),pmu=c(43,9,0.3),
	shape=~a*(nr==1)+sh*(nr>1),psh=-0.4,env=reps)
gnlr(surv,"gamma",mu=~a*(nr==1)+(b+c*sh)*(nr>1)+d2*treat2+d3*treat3,
	pmu=c(44,11.5,-0.09,-3.6,-1),shape=~a*(nr==1)+sh*(nr>1),
	psh=-0.4,env=reps)

# exponential dispersion model
gnlr(surv,"gamma",mu=~exp(a*(nr==1)+(b+c*y1)*(nr>1)),pmu=c(3.6,2.4,0.2),
	shape=~a*(nr==1)+b*sh*(nr>1),psh=c(-0.4,0.1),env=reps)
gnlr(surv,"gamma",mu=~exp(a*(nr==1)+(b+c*y1)*(nr>1)+d2*treat2+d3*treat3),
	pmu=c(3.6,2.4,0.2,0.4,0),shape=~a*(nr==1)+b*sh*(nr>1),psh=c(-0.4,0.1),
	env=reps)
gnlr(surv,"gamma",mu=~exp(a*(nr==1)+(b+c*y1)*(nr>1)+d2*treat2),
	pmu=c(3.6,2.4,0.2,0.4),shape=~a*(nr==1)+b*sh*(nr>1),psh=c(-0.4,0.1),
	env=reps)
gnlr(surv,"gamma",mu=~exp(a*(nr==1)+(b+c*y1)*(nr>1)+d2*treat2+e*(nr-1)),
	pmu=c(3.6,2.4,0.2,0.4,0),shape=~a*(nr==1)+b*sh*(nr>1),psh=c(-0.4,0.1),
	env=reps)
gnlr(surv,"gamma",mu=~exp(a*(nr==1)+b*(nr>1)+d2*treat2+e*(nr-1)),
	pmu=c(3.6,2.4,0.4,0),shape=~a*(nr==1)+b*sh*(nr>1),psh=c(-0.4,0.1),
	env=reps)
gnlr(surv,"gamma",mu=~exp(a*(nr==1)+b*(nr>1)+d2*treat2*(nr>1)
	+d3*(1-treat2)*(1-treat3)*(nr==1)+e*(nr-1)),
	pmu=c(3.7,2.8,-0.4,0.7,-0.1),shape=~a*(nr==1)+b*sh*(nr>1),
	psh=c(-0.4,0.1),env=reps)
