library(repeated)

ss <- read.table("locust.dat",skip=1)
s <- as.matrix(ss)
s1 <- as.matrix(ss[,seq(1,ncol(ss),by=2)])
s2 <- as.matrix(ss[,seq(2,ncol(ss),by=2)])
y <- restovec(t(s))
y1 <- restovec(t(s1))
y2 <- restovec(t(s2))

trend <- rep(1:161,24)
lag <- as.vector(rbind(rep(0,12),as.matrix(ss[1:160,])))
id <- gl(24,161)
treat <- gl(2,1932,3864)
trend1 <- rep(1:161,12)
lag1 <- as.vector(rbind(rep(0,12),s1[1:160,]))
lag2 <- as.vector(rbind(rep(0,12),s2[1:160,]))
id1 <- gl(12,161)

reps <- rmna(y, ccov=tcctomat(c(rep(0,12),rep(1,12)),names="treat"))

mu0 <- ~1
mu1 <- function(p)p[1:24]
mu1a <- function(p)p[1:12]
mu2 <- list(function(p)p*(1:161),function(p)p*(1:161))
mu3 <- ~b*(1:161)
mu4 <- list(function(p)p[1]+p[3]*(1:161),function(p)p[2]+p[3]*(1:161))
mu6 <- ~a+b*treat

# equivalently, using arrays
#mu0 <- function(p) cbind(rep(p[1],161),rep(p[2],161))
#mu1 <- function(p) matrix(p,ncol=2,byrow=T)
#mu2 <- function(p) matrix(rep(p*(1:161),2),ncol=2)
#mu3 <- function(p) cbind(p[1]*(1:161),p[2]*(1:161))
#mu4 <- function(p) cbind(p[1]+p[3]*(1:161),p[2]+p[3]*(1:161))
#mu6 <- function(p) cbind(c(rep(p[1],12),rep(p[2],12)),
#	c(rep(p[3],12),rep(p[4],12)))
#mu2a <- function(p) matrix(rep(p*(1:161),2),ncol=2)

#common intercept
print(u0 <- glm(as.vector(s)~1,family=binomial))
u0$aic/2
print(u1 <- glm(as.vector(s)~trend,family=binomial))
u1$aic/2

print(u2 <- glm(as.vector(s)~lag,family=binomial))
u2$aic/2
print(u3 <- glm(as.vector(s)~lag+trend,family=binomial))
u3$aic/2

print(z0 <- hidden(reps,pgamma=matrix(c(0.96,0.04,0.03,0.97),
	 ncol=2,byrow=T),tvmu=mu0,ptvmu=c(-1,-1)))
print(z2 <- hidden(reps,pgamma=matrix(c(0.96,0.04,0.03,0.97),
	 ncol=2,byrow=T),tvmu=mu4,ptvmu=c(-1,-1,0.014)))
rm(u0,u1,u2,u3,z0,z2)

# treatment intercepts
print(u8 <- glm(as.vector(s)~treat,family=binomial))
u8$aic/2
print(u9 <- glm(as.vector(s)~treat+trend,family=binomial))
u9$aic/2
print(u10 <- glm(as.vector(s)~treat*trend,family=binomial))
u10$aic/2

print(u11 <- glm(as.vector(s)~treat+lag,family=binomial))
u11$aic/2
print(u12 <- glm(as.vector(s)~treat+trend+lag,family=binomial))
u12$aic/2
print(u13 <- glm(as.vector(s)~treat*trend+lag,family=binomial))
u13$aic/2

print(z6 <- hidden(reps,pgamma=matrix(c(0.96,0.04,0.03,0.97),
	 ncol=2,byrow=T),cmu=mu6,pcmu=rep(-1,4),iter=200))
print(z7 <- hidden(reps,pgamma=matrix(c(0.99,0.01,0.02,0.98),
	 ncol=2,byrow=T),cmu=mu6,tvmu=mu2,pcmu=c(-3.5,0,0.8,0.55),
	 ptvmu=0.01,iter=200))
print(z8 <- hidden(reps,pgamma=matrix(c(0.99,0.01,0.02,0.98),
	 ncol=2,byrow=T),cmu=mu6,tvmu=mu3,pcmu=c(-4,-4,0,-0.65),iter=200,
	 ptvmu=c(0.01,0.01)))
rm(u8,u9,u10,u11,u12,u13,z6,z7,z8)

# individual intercepts
print(u7 <- glm(as.vector(s)~id,family=binomial))
u7$aic/2
print(u5 <- glm(as.vector(s)~trend+id,family=binomial))
u5$aic/2
print(u5a <- glm(as.vector(s1)~trend1+id1,family=binomial))
print(u5b <- glm(as.vector(s2)~trend1+id1,family=binomial))
u5a$aic/2+u5b$aic/2
rm(u7,u5,u5a,u5b)

print(u6 <- glm(as.vector(s)~lag+id,family=binomial))
u6$aic/2
print(u4 <- glm(as.vector(s)~lag+trend+id,family=binomial))
u4$aic/2
print(u4a <- glm(as.vector(s1)~lag1+trend1+id1,family=binomial))
u4a$aic/2
print(u4b <- glm(as.vector(s2)~lag2+trend1+id1,family=binomial))
u4a$aic/2+u4b$aic/2
rm(u6,u4,u4a,u4b)

print(z1 <- hidden(reps,pgamma=matrix(c(0.98,0.02,0.02,0.98),
	 ncol=2,byrow=T),cmu=mu1,pcmu=rep(-2,48),iter=200))
print(z3 <- hidden(reps,pgamma=matrix(c(0.98,0.02,0.02,0.98),
	ncol=2,byrow=T),cmu=mu1,tvmu=mu2,pcmu=rep(-2,48),ptvmu=0.01,iter=200))
print(z4 <- hidden(reps,pgamma=matrix(c(0.98,0.02,0.02,0.98),
	ncol=2,byrow=T),cmu=mu1,tvmu=mu3,pcmu=rep(-2,48),
	ptvmu=c(0.01,0.01),iter=200))
print(z5 <- hidden(reps,pgamma=matrix(c(0.98,0.02,0.02,0.98),
	ncol=2,byrow=T),mu=~individuals+times+I(treat*times),
	pmu=c(rep(c(rep(-2,24),rep(0.01,2)),2)),iter=300))
print(z3a <- hidden(y1,cmu=mu1a,tvmu=mu2,pcmu=rep(-1.5,24),iter=200,
	pgamma=matrix(c(0.975,0.025,0.055,0.945),ncol=2,byrow=T),ptvmu=0.014))
param <- t(matrix(c(-1.93,-0.08,-1.70,-1.01,-1.21,1.77,-0.23,0.94,0.06,-0.64,
	-3.80,-2.20,-0.96,-0.35,-1.75,-1.37,-2.36,-1.21,-0.51,-0.17,-2.56,
	-1.27,-1.19,-1.59),ncol=2,byrow=T))
param <- cbind(c(-29.5552,0.1692,2.1038,1.5847,-0.010096,
	-0.4677,1.062,-0.4446,0.987,1.46840,-1.9085,-4.3055),
	c(0.2378,-1.1521,-0.6583,-0.1552,-0.009642,-3.1167,-2.016,
	-15.7763,-1.506,-0.07219,-0.7359,-0.1334))
print(z3b <- hidden(y2,cmu=mu1a,tvmu=mu2,pcmu=param,iter=200,
	pgamma=matrix(c(0.975,0.025,0.025,0.975),ncol=2,byrow=T),ptvmu=0.01))
z3a$aic+z3b$aic
print(z6a <- hidden(y1,cmu=mu1a,tvmu=mu3,pcmu=rep(-1.5,24),iter=200,
	pgamma=matrix(c(0.975,0.025,0.055,0.945),ncol=2,byrow=T),
	ptvmu=c(0.014,0.014)))
param <- t(matrix(c(-1.93,-0.08,-1.70,-1.01,-1.21,1.77,-0.23,0.94,0.06,-0.64,
	-3.80,-2.20,-0.96,-0.35,-1.75,-1.37,-2.36,-1.21,-0.51,-0.17,-2.56,
	-1.27,-1.19,-1.59),ncol=2,byrow=T))
print(z6b <- hidden(y2,cmu=mu1a,tvmu=mu3,pcmu=param,iter=200,
	pgamma=matrix(c(0.975,0.025,0.025,0.975),ncol=2,byrow=T),
	ptvmu=c(0.01,0.01)))
z6a$aic+z6b$aic

if(interactive()){
postscript("locust.eps")
par(mfcol=c(4,2),font.main=1,mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot((1:161)/2,z3a$filt[2,covind(z3a)==1],type="l",xlab="",
	ylab=expression(pi[2]),main="Fed",ylim=c(0,1))
plot((1:161)/2,z3a$filt[2,covind(z3a)==2],type="l",xlab="",
	ylab=expression(pi[2]),ylim=c(0,1))
plot((1:161)/2,z3a$filt[2,covind(z3a)==5],type="l",xlab="",
	ylab=expression(pi[2]),ylim=c(0,1))
plot((1:161)/2,z3a$filt[2,covind(z3a)==7],type="l",xlab="Minutes",
	ylab=expression(pi[2]),ylim=c(0,1))
plot((1:161)/2,z3b$filt[1,covind(z3b)==1],type="l",xlab="",ylab="",
	main="Unfed",ylim=c(0,1))
plot((1:161)/2,z3b$filt[1,covind(z3b)==2],type="l",xlab="",ylab="",ylim=c(0,1))
plot((1:161)/2,z3b$filt[1,covind(z3b)==5],type="l",xlab="",ylab="",ylim=c(0,1))
plot((1:161)/2,z3b$filt[1,covind(z3b)==7],type="l",xlab="Minutes",ylab="",
	ylim=c(0,1))
dev.off()
}

#discretized Poisson process
print(zd0 <- chidden(reps,dist="disc",
	 pgamma=matrix(c(-0.033,0.033,0.022,-0.022),ncol=2,byrow=T),
	 tvmu=mu0,ptvmu=c(-1,-1)))
mexp(zd0$gamma)
print(zd2 <- chidden(reps,dist="disc",
	 pgamma=matrix(c(-0.033,0.033,0.022,-0.022),ncol=2,byrow=T),
	 tvmu=mu4,ptvmu=c(-1,-1,0.014)))
mexp(zd2$gamma)
param <- cbind(c(-8.81,-2.528,-2.621,-2.770,-4.516,-3.888,-13.880,-3.474,
	-13.63,-7.28,-12.563,-4.591),c(-3.77,-7.767,-15.972,-3.274,
	-2.141,-15.635,-7.467,-10.471,-11.49,-4.04,-4.656,-10.187))
print(zd6a <- chidden(y1,dist="disc",cmu=mu1a,tvmu=mu3,pcmu=param,
	iter=200,pgamma=matrix(c(-0.3,0.3,0.8,-0.8),ncol=2,byrow=T),
	ptvmu=c(-0.0015,0.14)))
mexp(zd6a$gamma)
param <- cbind(c(-12.252, 0.231, 2.1772, 1.6873,0.09587,-0.3892, 1.195,-0.3203,
	1.077, 1.6162,0.02003,-4.24114),c(0.282,-1.112,-0.6385,-0.1421,0.01389,
	-3.0968,-2.003,-15.7572,-1.473,-0.0435,-1.63171,-0.07718))
print(zd6b <- chidden(y2,dist="disc",cmu=mu1a,tvmu=mu3,pcmu=param,iter=200,
	pgamma=matrix(c(-0.033,0.033,0.022,-0.022),ncol=2,byrow=T),
	ptvmu=c(0.0042,0.0048)))
mexp(zd6b$gamma)
zd6a$aic+zd6b$aic
