library(ts)
library(growth)
library(gnlm)
library(repeated)

y <- scan("yale.dat",skip=1)
sy <- (y-mean(y))/sd(y)
times <- 1796:1975
dy <- diff(y)
sdy <- (dy-mean(dy))/sd(dy)
dtimes <- 1797:1975

if(interactive()){
postscript(file="yale.eps")
par(mfrow=c(3,1),mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(times,y,pch=20,xlab="",ylab="Enrolment",ylim=c(0,10000))
lines(times,y)
plot(dtimes,dy,pch=20,xlab="",ylab="Increase in enrolment",
	ylim=c(-1500,5500))
lines(dtimes,dy)
plot(dtimes,y[2:180]/y[1:179],pch=20,xlab="Year",ylab="Ratio of enrolments",
	ylim=c(0,3))
lines(dtimes,y[2:180]/y[1:179])
dev.off()
postscript(file="yalecorr.eps",height=5)
par(mfrow=c(1,2),mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0),font.main=1)
#acf(y,main="")
corgram(y,main="ACF",ylim=c(-0.2,1))
corgram(y,partial=T,main="PACF",ylab="",ylim=c(-0.2,1))
dev.off()
postscript(file="yalecorr2.eps",height=5)
par(mfrow=c(1,2),mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0),font.main=1)
#acf(dy,main="",ylab="")
corgram(dy,main="ACF",ylim=c(-0.2,1))
corgram(dy,partial=T,main="PACF",ylab="",ylim=c(-0.2,1))
dev.off()
}

# serial dependence
gnlr(y,dist="Poisson",mu=~exp(a),pmu=8)
gnlr(y,dist="negative binomial",mu=~exp(a),pmu=8.5,psh=-0.18)
gnlr(y,dist="negative binomial",mu=~exp(a),pmu=8.5,shape=~I(times-1795),
	psh=c(-0.18,0))
gar(y,dist="Poisson",link="log",preg=5,pdep=0.9)
print(zgar <- gar(y,times=times,dist="negative binomial",link="log",
	preg=4,psh=1,pdep=0.9))
print(zgart <- gar(y,times=times,dist="negative binomial",link="log",
	mu=~a+b*(times-1795),preg=c(5,0.02),psh=80,pdep=0.9))
print(zgartd <- gar(y,times=times,dist="negative binomial",link="log",
	mu=~a+(b+c*(times>1900))*(times-1795),preg=c(5,0.02,0),psh=80,
	pdep=0.9))
print(zgartd2 <- gar(y,times=times,dist="negative binomial",
	mu=~a+(b+c*(times>1900))*(times-1795),preg=c(120,0.2,0),
	psh=80,pdep=0.9))
print(zgars <- gar(y,times=times,dist="negative binomial",link="log",
	preg=5,shape=~exp(a+b*(times-1795)),psh=c(8,-0.02),pdep=0.9))
print(zgarts <- gar(y,times=times,dist="negative binomial",link="log",
	mu=~a+b*(times-1795),preg=c(5,0.02),shape=~exp(a+b*(times-1795)),
	psh=c(8,-0.02),pdep=0.9))
if(interactive()){
plot(times,(zgarts$coef[1]+zgarts$coef[2]*(times-1795))+
	(zgarts$coef[1]+zgarts$coef[2]*(times-1795))^2/
	exp(zgarts$coef[4]+zgarts$coef[5]*(times-1795)),
	type="l",ylab="Enrolment")
lines(times,zgarts$coef[1]+zgarts$coef[2]*(times-1795),lty=2)
}

# overdispersed gamma
kalcount(y,times=times-1795,preg=-8,pinit=1)
kalcount(y,times=times-1795,preg=-10,pinit=1,dep="frailty")
kalcount(y,times=times-1795,preg=-8,pinit=6,dep="serial",upd="serial",
	pdep=0.1)
print(zcum <- kalcount(y,times=times-1795,preg=-2,pinit=4.5,dep="serial",
	upd="cumulated",pdep=0.03))
kalcount(y,times=times-1795,preg=-8,pinit=6,dep="serial",upd="kalman",
	pdep=0.1)
kalcount(y,times=times-1795,preg=-8.5,pinit=5,dep="serial",upd="Markov",
	pdep=0.01)
print(zcnt <- kalcount(y,times=times-1795,preg=-8,pinit=6,dep="serial",
	upd="count",pdep=0.1))
print(zcntt <- kalcount(y,times=times-1795,mu=~exp(a+b*(times-1795)),
	ptvc=c(-8,0),pinit=6,dep="serial",upd="count",pdep=0.1))
print(zcntt2 <- kalcount(y,times=times-1795,mu=~a+b*(times-1795),
	ptvc=c(0.0085,-0.00001),pinit=6,dep="serial",upd="count",pdep=0.1))
print(zwcnt <- kalcount(y,times=times-1795,preg=-4,pinit=1,dep="serial",
	upd="count",pdep=0.03,int="Weibull",psh=1.3))
print(zwcnts <- kalcount(y,times=times-1795,preg=-3.6,pinit=0.1,dep="serial",
	upd="count",pdep=0.027,int="Weibull",shape=~exp(a+b*(times-1795)),
	psh=c(0.25,0.0001)))
print(zllcnt <- kalcount(y,times=times-1795,preg=-4,pinit=1,dep="serial",
	upd="count",pdep=0.03,int="log logistic",psh=1.3))
print(zgcnt <- kalcount(y,times=times-1795,preg=-4,pinit=1,dep="serial",
	upd="count",pdep=0.03,int="gamma",psh=1.3))

if(interactive()){
postscript(file="yalerpred.eps")
par(mfrow=c(3,1),mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(iprofile(zgar),pch=20,xlab="",ylab="Enrolment",main="",lty=2)
plot(iprofile(zgarts),pch=20,xlab="",ylab="Enrolment",,main="",lty=2)
plot(mprofile(zgarts),add=T)
legend(1800,8000,legend=c("Marginal profile","Recursive profile"),lty=1:2,
	bty="n")
plot(iprofile(zcnt),pch=20,xlab="Year",ylab="Enrolment",,main="",lty=2)
dev.off()
}

# Chapter 9

print(z1 <- glm(y[2:180]~y[1:179]))
z1$aic/2
print(z2 <- glm(y[2:180]~y[1:179]-1))
z2$aic/2
gar(y[2:180],preg=100,pdep=0.9,psh=var(y[2:180]))
print(z3 <- gar(y,mu=~rep(exp(a),180),preg=5,pdep=0.9,psh=var(y)))
exp(z3$coef[1])

# independence
print(zn <- elliptic(sdy,times=dtimes))
zn$aic+log(sd(dy))*length(dy)+1
print(znv <- elliptic(sdy,times=dtimes,varfn=~dtimes,preg=0,
	pvar=c(-104,0.054)))
znv$aic+log(sd(dy))*length(dy)+1
print(znv2 <- elliptic(sdy,times=dtimes,varfn=~I(dtimes>1900),preg=0,
	pvar=c(-4,5.2)))
znv2$aic+log(sd(dy))*length(dy)+1
print(znv3 <- elliptic(sdy,times=dtimes,varfn=~sy[1:179],preg=0,
	pvar=c(-0.5,4)))
znv3$aic+log(sd(dy))*length(dy)+1

# AR(1)
print(znar <- elliptic(sdy,times=dtimes,par=0.1))
znar$aic+log(sd(dy))*length(dy)+1
print(znarv <- elliptic(sdy,times=dtimes,varfn=~dtimes,preg=0,
	pvar=c(-104,0.054),par=0.001))
znarv$aic+log(sd(dy))*length(dy)+1

if(interactive()){
postscript(file="yalevar.eps",height=5,width=5)
par(mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(dtimes,exp(znv$coef[2]+znv$coef[3]*dtimes)*var(dy),type="l",
	xlab="Year",ylab=expression(sigma^2))
lines(dtimes,exp(znv2$coef[2]+znv2$coef[3]*(dtimes>1900))*var(dy),lty=2)
#lines(dtimes,exp(znv3$coef[2]+znv3$coef[3]*sy[1:179])*var(dy),lty=3)
legend(1800,2000000,legend=c("Log linear","Break at 1900"),lty=1:2,bty="n")
dev.off()
}

z <- pergram(y)

mu1 <- function(p)exp(p[1])/((p[2]*sin(z[,1]))^2+(1+p[2]*cos(z[,1]))^2)
mu2 <- function(p)exp(p[1])/((p[2]*sin(z[,1])+p[3]*sin(2*z[,1]))^2+
	(1+p[2]*cos(z[,1])+p[3]*cos(2*z[,1]))^2)
gnlr(z[,2],dist="exponential",mu=~exp(a),pmu=24)
gnlr(z[,2],dist="exponential",mu=mu1,pmu=c(24,0))
gnlr(z[,2],dist="exponential",mu=mu2,pmu=c(24,0,0))

mub1 <- function(p)exp(p[1]+2*p[2]*cos(z[,1]))
mub2 <- function(p)exp(p[1]+2*p[2]*cos(z[,1])+2*p[3]*cos(2*z[,1]))
mub3 <- function(p)exp(p[1]+2*p[2]*cos(z[,1])+2*p[3]*cos(2*z[,1])+
	2*p[4]*cos(4*z[,1]))
mub4 <- function(p)exp(p[1]+2*p[2]*cos(z[,1])+2*p[3]*cos(2*z[,1])+
	2*p[4]*cos(4*z[,1])+2*p[5]*cos(6*z[,1]))
mub5 <- function(p)exp(p[1]+2*p[2]*cos(z[,1])+2*p[3]*cos(2*z[,1])+
	2*p[4]*cos(4*z[,1])+2*p[5]*cos(6*z[,1])+2*p[6]*cos(8*z[,1]))
mub6 <- function(p)exp(p[1]+2*p[2]*cos(z[,1])+2*p[3]*cos(2*z[,1])+
	2*p[4]*cos(4*z[,1])+2*p[5]*cos(6*z[,1])+2*p[6]*cos(8*z[,1])+
	2*p[7]*cos(10*z[,1]))
mub7 <- function(p)exp(p[1]+2*p[2]*cos(z[,1])+2*p[3]*cos(2*z[,1])+
	2*p[4]*cos(4*z[,1])+2*p[5]*cos(6*z[,1])+2*p[6]*cos(8*z[,1])+
	2*p[7]*cos(10*z[,1])+2*p[8]*cos(12*z[,1]))
gnlr(z[,2],dist="exponential",mu=mub1,pmu=c(30,1))
gnlr(z[,2],dist="exponential",mu=mub2,pmu=c(24,1.4,0))
gnlr(z[,2],dist="exponential",mu=mub3,pmu=c(24,1.2,0.6,0))
gnlr(z[,2],dist="exponential",mu=mub4,pmu=c(22,1,0.6,0.3,0))
gnlr(z[,2],dist="exponential",mu=mub5,pmu=c(22,1,0.6,0.3,0.3,0))
gnlr(z[,2],dist="exponential",mu=mub6,pmu=c(22,1,0.6,0.3,0.3,0.2,0))
gnlr(z[,2],dist="exponential",mu=mub7,pmu=c(22,1,0.6,0.3,0.3,0.2,0.2,0))

z <- pergram(dy)

gnlr(z[,2],dist="exponential",mu=~exp(a),pmu=24)
gnlr(z[,2],dist="exponential",mu=mu1,pmu=c(24,0))
gnlr(z[,2],dist="exponential",mu=mu2,pmu=c(24,0,0))

gnlr(z[,2],dist="exponential",mu=mub1,pmu=c(30,1))
gnlr(z[,2],dist="exponential",mu=mub2,pmu=c(24,1.4,0))
