library(gnlm)
library(event)

data <- read.list("sperm.dat",skip=7,n=1)
entry <- exit <- NULL
birth <- list()
for(i in 1:length(data)){
	len <- length(data[[i]])
	entry <- c(entry,data[[i]][1])
	exit <- c(exit,data[[i]][3])
	birth <- c(birth,list(c(0,cumsum(data[[i]][4:(len-1)]))))
	data[[i]] <- cbind(data[[i]][4:len],
		seq(data[[i]][1],data[[i]][3],length=len-3))}
reps <- rmna(data,ccov=tcctomat(cbind(entry,exit),names=c("entry","exit")),
	tvcov=tvctomat(birth))

if(interactive()){
postscript("sperm.eps",height=5,width=5)
par(mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
cprocess(events=reps,xlim=c(10,20),xlab="Age",ylab="Positive sperm samples")
dev.off()
}

gnlr(reps,dist="binomial",mu=~1/(1+exp(-a)),pmu=-1)
gnlr(reps,dist="binomial",mu=~1/(1+exp(-a-b*entry)),pmu=c(-5,0.4))
gnlr(reps,dist="binomial",mu=~1/(1+exp(-a-c*birth)),pmu=c(-2,0))
gnlr(reps,dist="binomial",mu=~1/(1+exp(-a-d*times)),pmu=c(-3,0.2))
gnlr(reps,dist="binomial",mu=~1/(1+exp(-a-c*birth-d*times)),pmu=c(-3,0.1,0.1))
gnlr(reps,dist="binomial",mu=~1/(1+exp(-a-b*entry-c*birth-d*times)),
	pmu=c(-8,0.5,0.1,0.1))
gnlr(reps,dist="binomial",pmu=c(-7,0.3,1,0.2,0),
	mu=~1/(1+exp(-a-b*entry-c*birth-d*times-cd*birth*times)))
gnlr(reps,dist="binomial",pmu=c(-7,1,0.2,0),
	mu=~1/(1+exp(-a-c*birth-d*times-cd*birth*times)))
gnlr(reps,dist="binomial",pmu=c(-7,4,0.2,-0.2),
	mu=~1/(1+exp(-a-c2*(birth>0)-d*times-c2d*(birth>0)*times)))
gnlr(reps,dist="binomial",pmu=c(-7,4,0.2),
	mu=~1/(1+exp(-a-c2*(birth>0)-c2d*(birth==0)*times)))
gnlr(reps,dist="binomial",pmu=c(-7,0,0.2),
	mu=~1/(1+exp(-a-c*birth-c2d*(birth==0)*times)))
gnlr(reps,dist="binomial",pmu=c(-7,0,4,0.2),
	mu=~1/(1+exp(-a-c*birth-c2*(birth>0)-c2d*(birth==0)*times)))
