library(ts)
library(growth)

data <- read.table("bronchitis.dat",skip=2,header=T)
attach(data)
admales <- (Males-mean(Males))/sd(Males)
males <- ts(admales,freq=12)
times <- 1:72

if(interactive()){
postscript(file="bronchitis.eps",height=5)
par(mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(times,Males,pch=20,xlab="Month",ylab="Respiratory cases",ylim=c(0,3000))
lines(times,Males)
dev.off()
postscript(file="bronchitisACF.eps",height=5)
par(mfrow=c(1,2),mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0),font.main=1)
#acf(males,main="")
#pacf(males,main="")
corgram(admales,main="ACF",ylim=c(-1,1))
corgram(admales,partial=T,main="PACF",ylab="",ylim=c(-1,1))
dev.off()
}
arima0(males,order=c(1,0,0))

# normal distribution (AICs corrected for standardization including 1
# for intercept
# independence
print(zn <- elliptic(admales,times=times))
zn$aic+log(sd(Males))*length(Males)+1
print(znt <- elliptic(admales,times=times,model=~times,preg=c(0,0)))
znt$aic+log(sd(Males))*length(Males)+1
print(znseas <- elliptic(admales,times=times,
	model=~a*cos(b+pi*times/6),preg=c(0,0)))
znseas$aic+log(sd(Males))*length(Males)+1
print(znseas2 <- elliptic(admales,times=times,pvar=0.2,
	model=~a1*cos(b1+pi*times/6)+a2*cos(b2+pi*times/3),
	preg=c(1.2,-1,0,0)))
znseas2$aic+log(sd(Males))*length(Males)+1
print(znseas3 <- elliptic(admales,times=times,pvar=0.17,
	model=~a1*cos(b1+pi*times/6)+a2*cos(b2+pi*times/3)+
	a3*cos(b3+pi*times/1.5),preg=c(1.2,-1,-0.25,1.5,0,0)))
znseas3$aic+log(sd(Males))*length(Males)+1
print(znseast <- elliptic(admales,times=times,
	model=~a*cos(b+pi*times/6)+c*times,preg=c(1.2,-1,0)))
znseast$aic+log(sd(Males))*length(Males)+1
print(znseas2t <- elliptic(admales,times=times,pvar=0.2,
	model=~a1*cos(b1+pi*times/6)+a2*cos(b2+pi*times/3)+c*times,
	preg=c(1.2,-1,-0.25,1.5,0)))
znseas2t$aic+log(sd(Males))*length(Males)+1

# AR(1)
print(znar <- elliptic(admales,times=times,par=0.7))
znar$aic+log(sd(Males))*length(Males)+1
print(znart <- elliptic(admales,times=times,model=~times,preg=c(0,0),par=0.7))
znart$aic+log(sd(Males))*length(Males)+1
print(znarseas <- elliptic(admales,times=times,
	model=~a*cos(b+pi*times/6),preg=c(0,0),par=0.7))
znarseas$aic+log(sd(Males))*length(Males)+1
print(znarseas2 <- elliptic(admales,times=times,pvar=0.2,
	model=~a1*cos(b1+pi*times/6)+a2*cos(b2+pi*times/3),
	preg=c(1.2,-1,0,0),par=0.35))
znarseas2$aic+log(sd(Males))*length(Males)+1
print(znarseas3 <- elliptic(admales,times=times,pvar=0.17,
	model=~a1*cos(b1+pi*times/6)+a2*cos(b2+pi*times/3)+
	a3*cos(b3+pi*times/1.5),preg=c(1.2,-1,-0.25,1.5,0,0),par=0.3))
znarseas3$aic+log(sd(Males))*length(Males)+1
print(znarseast <- elliptic(admales,times=times,
	model=~a*cos(b+pi*times/6)+c*times,preg=c(1.2,-1,0),par=0.7))
znarseast$aic+log(sd(Males))*length(Males)+1
print(znarseas2t <- elliptic(admales,times=times,pvar=0.2,
	model=~a1*cos(b1+pi*times/6)+a2*cos(b2+pi*times/3)+c*times,
	preg=c(1.2,-1,-0.25,1.5,0),par=0.35))
znarseas2t$aic+log(sd(Males))*length(Males)+1

if(interactive()){
postscript(file="bronchitisAR.eps",height=5)
par(mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(times,Males,pch=20,xlab="Month",ylab="Respiratory cases",ylim=c(0,3000))
# transform back to original scale
lines(times,fitted(znarseas2t,recursive=T)*sd(Males)+mean(Males),lty=3)
lines(times,fitted(znarseas2t)*sd(Males)+mean(Males))
legend(0,500,legend=c("Underlying profile","Recursive prediction"),
	lty=1:2,bty="n")
dev.off()
postscript(file="bronchitisAR2.eps",height=5)
par(mfrow=c(1,2),mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0),font.main=1)
#acf(residuals(znarseas2t,recursive=T),main="")
corgram(residuals(znarseas2t,recursive=T),main="ACF")
corgram(residuals(znarseas2t,recursive=T),partial=T,ylab="",main="PACF")
dev.off()
}

# log normal distribution
#independence
elliptic(Males,times=times,pvar=0.08,transform="log")
elliptic(Males,times=times,model=~times,preg=c(7,0),pvar=0.08,transform="log")
print(zlnseas <- elliptic(Males,times=times,transform="log",
	model=~d+a*cos(b+pi*times/6),preg=c(7,0,0),pvar=0.08))
print(zlnseas2 <- elliptic(Males,times=times,transform="log",
	model=~d+a*cos(b+pi*times/6)+a2*cos(b2+pi*times/3),
	preg=c(7,0.3,-1,0,0),pvar=0.08))
print(zlnseas3 <- elliptic(Males,times=times,transform="log",pvar=0.08,
	model=~d+a*cos(b+pi*times/6)+a2*cos(b2+pi*times/3)+
	a3*cos(b3+pi*times/1.5),preg=c(7,0.3,-1,0.05,-1.3,0,0)))
print(zlnseas2t <- elliptic(Males,times=times,transform="log",
	model=~d+a*cos(b+pi*times/6)+a2*cos(b2+pi*times/3)+c*times,
	preg=c(7,0.3,-1,0.05,-1.3,0),pvar=0.08))
print(zlnseas3t <- elliptic(Males,times=times,transform="log",pvar=0.008,
	model=~d+a*cos(b+pi*times/6)+a2*cos(b2+pi*times/3)+
	a3*cos(b3+pi*times/1.5)+c*times,
	preg=c(7.4,0.35,-1,0.05,-1.3,-0.03,1.5,-0.003)))

# AR(1)
elliptic(Males,times=times,pvar=0.08,par=0.7,transform="log")
elliptic(Males,times=times,model=~times,preg=c(7,0),par=0.7,pvar=0.08,
	transform="log")
print(zlnarseas <- elliptic(Males,times=times,transform="log",
	model=~d+a*cos(b+pi*times/6),preg=c(7,0,0),pvar=0.08,par=0.7))
print(zlnarseas2 <- elliptic(Males,times=times,transform="log",
	model=~d+a*cos(b+pi*times/6)+a2*cos(b2+pi*times/3),
	preg=c(7,0.3,-1,0,0),pvar=0.08,par=0.7))
print(zlnarseas3 <- elliptic(Males,times=times,transform="log",pvar=0.08,
	model=~d+a*cos(b+pi*times/6)+a2*cos(b2+pi*times/3)+
	a3*cos(b3+pi*times/1.5),preg=c(7,0.3,-1,0.05,-1.3,0,0),par=0.7))
print(zlnarseas2t <- elliptic(Males,times=times,transform="log",
	model=~d+a*cos(b+pi*times/6)+a2*cos(b2+pi*times/3)+c*times,
	preg=c(7,0.3,-1,0.05,-1.3,0),pvar=0.08,par=0.7))

if(interactive()){
postscript(file="bronchitisLNAR.eps",height=5)
par(mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(times,Males,pch=20,xlab="Month",ylim=c(0,3000),ylab="Respiratory cases")
plot(mprofile(zlnseas2t),add=T)
dev.off()
postscript(file="bronchitisLNAR2.eps",height=5)
par(mfrow=c(1,2),mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0),font.main=1)
#acf(residuals(zlnseas2t),main="")
corgram(residuals(zlnseas2t),main="ACF")
corgram(residuals(zlnseas2t),partial=T,ylab="",main="PACF")
dev.off()
}

# spectrum
z <- pergram(Males)
zs <- (z[1:34,2]+z[2:35,2]+z[3:36,2])/3
if(interactive()){
postscript(file="bronchitisspec.eps",height=5)
par(mfrow=c(1,2),mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0),font.main=1)
plot(z)
plot(z[2:35,1],zs,type="l",xlab="Frequency",ylab="",xlim=c(0,3.5),
	ylim=c(0,max(z[,2])))
#spectrum(males,main="",xlab="Frequency",ylab="Spectrum")
#spectrum(males,span=c(3,5),main="",xlab="Frequency",ylab="")
dev.off()

postscript(file="bronchitiscspec.eps",height=5,width=5)
par(mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0),font.main=1)
plot.cum(z,main="",ylab="Cumulative periodogram")
#cpgram(males)
dev.off()
}
